@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2020 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2021 Savoir-faire Linux Inc.
  *
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
  *  Author: Laurielle Lea <laurielle.lea@savoirfairelinux.com>
@@ -22,13 +22,17 @@
 
 #include "call.h"
 #include "account.h"
+#include "jamidht/jamiaccount.h"
 #include "manager.h"
+#ifdef ENABLE_PLUGIN
+#include "plugin/jamipluginmanager.h"
+#include "plugin/streamdata.h"
+#endif
 #include "audio/ringbufferpool.h"
-#include "dring/call_const.h"
+#include "jami/call_const.h"
 #include "client/ring_signal.h"
 #include "sip/sip_utils.h"
 #include "ip_utils.h"
-#include "array_size.h"
 #include "map_utils.h"
 #include "call_factory.h"
 #include "string_utils.h"
@@ -36,6 +40,8 @@
 
 #include "errno.h"
 
+#include <opendht/thread_pool.h>
+
 #include <stdexcept>
 #include <system_error>
 #include <algorithm>
@@ -50,34 +56,31 @@ namespace jami {
 /// calls the unary predicate \a pred with this call pointer and hangup the call with given error
 /// code \a errcode when the predicate return true.
 /// The predicate should have <code>bool(Call*) signature</code>.
+template<typename T>
 inline void
-hangupCallsIf(const Call::SubcallSet& callptr_list, int errcode, const std::function<bool(Call*)>& pred)
+hangupCallsIf(Call::SubcallSet&& calls, int errcode, T pred)
 {
-    std::for_each(std::begin(callptr_list), std::end(callptr_list),
-                  [&](const std::shared_ptr<Call>& call_ptr) {
-                      if (pred(call_ptr.get())) {
-                          try {
-                              call_ptr->hangup(errcode);
-                          } catch (const std::exception& e) {
-                              JAMI_ERR("[call:%s] hangup failed: %s",
-                                       call_ptr->getCallId().c_str(), e.what());
-                          }
-                      }
-                  });
+    for (auto& call : calls) {
+        if (not pred(call.get()))
+            continue;
+        dht::ThreadPool::io().run([call = std::move(call), errcode] { call->hangup(errcode); });
+    }
 }
 
 /// Hangup many calls with same error code.
 ///
 /// Works as hangupCallsIf() with a predicate that always return true.
 inline void
-hangupCalls(const Call::SubcallSet& callptr_list, int errcode)
+hangupCalls(Call::SubcallSet&& callptr_list, int errcode)
 {
-    hangupCallsIf(callptr_list, errcode, [](Call*){ return true; });
+    hangupCallsIf(std::move(callptr_list), errcode, [](Call*) { return true; });
 }
 
 //==============================================================================
 
-Call::Call(Account& account, const std::string& id, Call::CallType type,
+Call::Call(const std::shared_ptr<Account>& account,
+           const std::string& id,
+           Call::CallType type,
            const std::map<std::string, std::string>& details)
     : id_(id)
     , type_(type)
@@ -88,31 +91,9 @@ Call::Call(Account& account, const std::string& id, Call::CallType type,
     addStateListener([this](Call::CallState call_state,
                             Call::ConnectionState cnx_state,
                             UNUSED int code) {
-
-        if (cnx_state == ConnectionState::PROGRESSING
-            && startFallback_.exchange(false)
-            && not isSubcall()) {
-            // If the other peer lose the connectivity during the progressing
-            // this means that the other peer had a connectivity change we didn't
-            // detect for now.
-            // In this case, we let two secs before sending a request via the DHT
-            // just to bypass the CONNECTING status
-
-            std::weak_ptr<Call> callWkPtr = shared_from_this();
-            Manager::instance().scheduler().scheduleIn([callWkPtr]{
-                if (auto callShPtr = callWkPtr.lock()) {
-                    if (callShPtr->getConnectionState() == Call::ConnectionState::PROGRESSING) {
-                        JAMI_WARN("Call %s is still connecting after timeout, sending fallback request",
-                            callShPtr->getCallId().c_str());
-                        if (callShPtr->onNeedFallback_) callShPtr->onNeedFallback_();
-                    }
-                }
-            }, std::chrono::seconds(2));
-        }
-
         checkPendingIM();
         std::weak_ptr<Call> callWkPtr = shared_from_this();
-        runOnMainThread([callWkPtr]{
+        runOnMainThread([callWkPtr] {
             if (auto call = callWkPtr.lock())
                 call->checkAudio();
         });
@@ -122,17 +103,32 @@ Call::Call(Account& account, const std::string& id, Call::CallType type,
             auto timeout = Manager::instance().getRingingTimeout();
             JAMI_DBG("Scheduling call timeout in %d seconds", timeout);
 
-           std::weak_ptr<Call> callWkPtr = shared_from_this();
-           Manager::instance().scheduler().scheduleIn([callWkPtr]{
-               if (auto callShPtr = callWkPtr.lock()) {
-                    if (callShPtr->getConnectionState() == Call::ConnectionState::RINGING) {
-                         JAMI_DBG("Call %s is still ringing after timeout, setting state to BUSY",
-                             callShPtr->getCallId().c_str());
-                         callShPtr->hangup(PJSIP_SC_BUSY_HERE);
-                         Manager::instance().callFailure(*callShPtr);
+            std::weak_ptr<Call> callWkPtr = shared_from_this();
+            Manager::instance().scheduler().scheduleIn(
+                [callWkPtr] {
+                    if (auto callShPtr = callWkPtr.lock()) {
+                        if (callShPtr->getConnectionState() == Call::ConnectionState::RINGING) {
+                            JAMI_DBG(
+                                "Call %s is still ringing after timeout, setting state to BUSY",
+                                callShPtr->getCallId().c_str());
+                            callShPtr->hangup(PJSIP_SC_BUSY_HERE);
+                            Manager::instance().callFailure(*callShPtr);
+                        }
                     }
+                },
+                std::chrono::seconds(timeout));
+        }
+
+        if (!isSubcall() && getCallType() == CallType::OUTGOING) {
+            if (cnx_state == ConnectionState::CONNECTED && duration_start_ == time_point::min())
+                duration_start_ = clock::now();
+            else if (cnx_state == ConnectionState::DISCONNECTED && call_state == CallState::OVER) {
+                if (auto jamiAccount = std::dynamic_pointer_cast<JamiAccount>(getAccount().lock())) {
+                    jamiAccount->convModule()->addCallHistoryMessage(getPeerNumber(),
+                                                                     getCallDuration().count());
+                    monitor();
                 }
-           }, std::chrono::seconds(timeout));
+            }
         }
 
         // kill pending subcalls at disconnect
@@ -141,12 +137,14 @@ Call::Call(Account& account, const std::string& id, Call::CallType type,
     });
 
     time(&timestamp_start_);
-    account_.attachCall(id_);
+    if (auto shared = account_.lock())
+        shared->attachCall(id_);
 }
 
 Call::~Call()
 {
-    account_.detachCall(id_);
+    if (auto shared = account_.lock())
+        shared->detachCall(id_);
 }
 
 void
@@ -159,10 +157,13 @@ Call::removeCall()
         Recordable::stopRecording();
 }
 
-const std::string&
+std::string
 Call::getAccountId() const
 {
-    return account_.getAccountID();
+    if (auto shared = account_.lock())
+        return shared->getAccountID();
+    JAMI_ERR("No account detected");
+    return {};
 }
 
 Call::ConnectionState
@@ -191,62 +192,68 @@ Call::validStateTransition(CallState newState)
         return true;
 
     switch (callState_) {
-        case CallState::INACTIVE:
-            switch (newState) {
-                case CallState::ACTIVE:
-                case CallState::BUSY:
-                case CallState::PEER_BUSY:
-                case CallState::MERROR:
-                    return true;
-                default: // INACTIVE, HOLD
-                    return false;
-            }
-
+    case CallState::INACTIVE:
+        switch (newState) {
         case CallState::ACTIVE:
-            switch (newState) {
-                case CallState::BUSY:
-                case CallState::PEER_BUSY:
-                case CallState::HOLD:
-                case CallState::MERROR:
-                    return true;
-                default: // INACTIVE, ACTIVE
-                    return false;
-            }
-
-        case CallState::HOLD:
-            switch (newState) {
-                case CallState::ACTIVE:
-                case CallState::MERROR:
-                    return true;
-                default: // INACTIVE, HOLD, BUSY, PEER_BUSY, MERROR
-                    return false;
-            }
-
         case CallState::BUSY:
-            switch (newState) {
-                case CallState::MERROR:
-                    return true;
-                default: // INACTIVE, ACTIVE, HOLD, BUSY, PEER_BUSY
-                    return false;
-            }
-
-        default: // MERROR
+        case CallState::PEER_BUSY:
+        case CallState::MERROR:
+            return true;
+        default: // INACTIVE, HOLD
             return false;
+        }
+
+    case CallState::ACTIVE:
+        switch (newState) {
+        case CallState::BUSY:
+        case CallState::PEER_BUSY:
+        case CallState::HOLD:
+        case CallState::MERROR:
+            return true;
+        default: // INACTIVE, ACTIVE
+            return false;
+        }
+
+    case CallState::HOLD:
+        switch (newState) {
+        case CallState::ACTIVE:
+        case CallState::MERROR:
+            return true;
+        default: // INACTIVE, HOLD, BUSY, PEER_BUSY, MERROR
+            return false;
+        }
+
+    case CallState::BUSY:
+        switch (newState) {
+        case CallState::MERROR:
+            return true;
+        default: // INACTIVE, ACTIVE, HOLD, BUSY, PEER_BUSY
+            return false;
+        }
+
+    default: // MERROR
+        return false;
     }
 }
 
 bool
 Call::setState(CallState call_state, ConnectionState cnx_state, signed code)
 {
-    std::lock_guard<std::recursive_mutex> lock(callMutex_);
-    JAMI_DBG("[call:%s] state change %u/%u, cnx %u/%u, code %d", id_.c_str(),
-             (unsigned)callState_, (unsigned)call_state, (unsigned)connectionState_,
-             (unsigned)cnx_state, code);
+    std::unique_lock<std::recursive_mutex> lock(callMutex_);
+    JAMI_DBG("[call:%s] state change %u/%u, cnx %u/%u, code %d",
+             id_.c_str(),
+             (unsigned) callState_,
+             (unsigned) call_state,
+             (unsigned) connectionState_,
+             (unsigned) cnx_state,
+             code);
 
     if (callState_ != call_state) {
         if (not validStateTransition(call_state)) {
             JAMI_ERR("[call:%s] invalid call state transition from %u to %u",
-                     id_.c_str(), (unsigned)callState_, (unsigned)call_state);
+                     id_.c_str(),
+                     (unsigned) callState_,
+                     (unsigned) call_state);
             return false;
         }
     } else if (connectionState_ == cnx_state)
@@ -264,7 +271,10 @@ Call::setState(CallState call_state, ConnectionState cnx_state, signed code)
     if (old_client_state != new_client_state) {
         if (not parent_) {
             JAMI_DBG("[call:%s] emit client call state change %s, code %d",
-                     id_.c_str(), new_client_state.c_str(), code);
+                     id_.c_str(),
+                     new_client_state.c_str(),
+                     code);
+            lock.unlock();
             emitSignal<DRing::CallSignal::StateChange>(id_, new_client_state, code);
         }
     }
@@ -292,54 +302,54 @@ Call::getStateStr() const
     using namespace DRing::Call;
 
     switch (getState()) {
-        case CallState::ACTIVE:
-            switch (getConnectionState()) {
-                case ConnectionState::PROGRESSING:
-                    return StateEvent::CONNECTING;
+    case CallState::ACTIVE:
+        switch (getConnectionState()) {
+        case ConnectionState::PROGRESSING:
+            return StateEvent::CONNECTING;
 
-                case ConnectionState::RINGING:
-                    return isIncoming() ? StateEvent::INCOMING : StateEvent::RINGING;
+        case ConnectionState::RINGING:
+            return isIncoming() ? StateEvent::INCOMING : StateEvent::RINGING;
 
-                case ConnectionState::DISCONNECTED:
-                    return StateEvent::HUNGUP;
+        case ConnectionState::DISCONNECTED:
+            return StateEvent::HUNGUP;
 
-                case ConnectionState::CONNECTED:
-                default:
-                    return StateEvent::CURRENT;
-            }
-
-        case CallState::HOLD:
-            if(getConnectionState() == ConnectionState::DISCONNECTED)
-                return StateEvent::HUNGUP;
-            return StateEvent::HOLD;
-
-        case CallState::BUSY:
-            return StateEvent::BUSY;
-
-        case CallState::PEER_BUSY:
-            return StateEvent::PEER_BUSY;
-
-        case CallState::INACTIVE:
-            switch (getConnectionState()) {
-                case ConnectionState::PROGRESSING:
-                    return StateEvent::CONNECTING;
-
-                case ConnectionState::RINGING:
-                    return isIncoming() ? StateEvent::INCOMING : StateEvent::RINGING;
-
-                case ConnectionState::CONNECTED:
-                    return StateEvent::CURRENT;
-
-                default:
-                    return StateEvent::INACTIVE;
-            }
-
-        case CallState::OVER:
-            return StateEvent::OVER;
-
-        case CallState::MERROR:
+        case ConnectionState::CONNECTED:
         default:
-            return StateEvent::FAILURE;
+            return StateEvent::CURRENT;
+        }
+
+    case CallState::HOLD:
+        if (getConnectionState() == ConnectionState::DISCONNECTED)
+            return StateEvent::HUNGUP;
+        return StateEvent::HOLD;
+
+    case CallState::BUSY:
+        return StateEvent::BUSY;
+
+    case CallState::PEER_BUSY:
+        return StateEvent::PEER_BUSY;
+
+    case CallState::INACTIVE:
+        switch (getConnectionState()) {
+        case ConnectionState::PROGRESSING:
+            return StateEvent::CONNECTING;
+
+        case ConnectionState::RINGING:
+            return isIncoming() ? StateEvent::INCOMING : StateEvent::RINGING;
+
+        case ConnectionState::CONNECTED:
+            return StateEvent::CURRENT;
+
+        default:
+            return StateEvent::INACTIVE;
+        }
+
+    case CallState::OVER:
+        return StateEvent::OVER;
+
+    case CallState::MERROR:
+    default:
+        return StateEvent::FAILURE;
     }
 }
 
@@ -362,16 +372,19 @@ std::map<std::string, std::string>
 Call::getDetails() const
 {
     return {
-        {DRing::Call::Details::CALL_TYPE,        std::to_string((unsigned)type_)},
-        {DRing::Call::Details::PEER_NUMBER,      peerNumber_},
-        {DRing::Call::Details::DISPLAY_NAME,     peerDisplayName_},
-        {DRing::Call::Details::CALL_STATE,       getStateStr()},
-        {DRing::Call::Details::CONF_ID,          confID_},
-        {DRing::Call::Details::TIMESTAMP_START,  std::to_string(timestamp_start_)},
-        {DRing::Call::Details::ACCOUNTID,        getAccountId()},
-        {DRing::Call::Details::AUDIO_MUTED,      std::string(bool_to_str(isAudioMuted_))},
-        {DRing::Call::Details::VIDEO_MUTED,      std::string(bool_to_str(isVideoMuted_))},
-        {DRing::Call::Details::AUDIO_ONLY,       std::string(bool_to_str(isAudioOnly_))},
+
+        {DRing::Call::Details::CALL_TYPE, std::to_string((unsigned) type_)},
+        {DRing::Call::Details::PEER_NUMBER, peerNumber_},
+        {DRing::Call::Details::DISPLAY_NAME, peerDisplayName_},
+        {DRing::Call::Details::CALL_STATE, getStateStr()},
+        {DRing::Call::Details::CONF_ID, confID_},
+        {DRing::Call::Details::TIMESTAMP_START, std::to_string(timestamp_start_)},
+        {DRing::Call::Details::ACCOUNTID, getAccountId()},
+        {DRing::Call::Details::AUDIO_MUTED,
+         std::string(bool_to_str(isCaptureDeviceMuted(MediaType::MEDIA_AUDIO)))},
+        {DRing::Call::Details::VIDEO_MUTED,
+         std::string(bool_to_str(isCaptureDeviceMuted(MediaType::MEDIA_VIDEO)))},
+        {DRing::Call::Details::AUDIO_ONLY, std::string(bool_to_str(not hasVideo()))},
     };
 }
 
@@ -379,15 +392,15 @@ std::map<std::string, std::string>
 Call::getNullDetails()
 {
     return {
-        {DRing::Call::Details::CALL_TYPE,        "0"},
-        {DRing::Call::Details::PEER_NUMBER,      ""},
-        {DRing::Call::Details::DISPLAY_NAME,     ""},
-        {DRing::Call::Details::CALL_STATE,       "UNKNOWN"},
-        {DRing::Call::Details::CONF_ID,          ""},
-        {DRing::Call::Details::TIMESTAMP_START,  ""},
-        {DRing::Call::Details::ACCOUNTID,        ""},
-        {DRing::Call::Details::VIDEO_SOURCE,     "UNKNOWN"},
-        {DRing::Call::Details::AUDIO_ONLY,       ""},
+        {DRing::Call::Details::CALL_TYPE, "0"},
+        {DRing::Call::Details::PEER_NUMBER, ""},
+        {DRing::Call::Details::DISPLAY_NAME, ""},
+        {DRing::Call::Details::CALL_STATE, "UNKNOWN"},
+        {DRing::Call::Details::CONF_ID, ""},
+        {DRing::Call::Details::TIMESTAMP_START, ""},
+        {DRing::Call::Details::ACCOUNTID, ""},
+        {DRing::Call::Details::VIDEO_SOURCE, "UNKNOWN"},
+        {DRing::Call::Details::AUDIO_ONLY, ""},
     };
 }
 
@@ -400,6 +413,13 @@ Call::onTextMessage(std::map<std::string, std::string>&& messages)
         return;
     }
 
+    it = messages.find("application/confOrder+json");
+    if (it != messages.end()) {
+        if (auto conf = Manager::instance().getConferenceFromID(confID_))
+            conf->onConfOrder(getCallId(), it->second);
+        return;
+    }
+
     {
         std::lock_guard<std::recursive_mutex> lk {callMutex_};
         if (parent_) {
@@ -407,6 +427,16 @@ Call::onTextMessage(std::map<std::string, std::string>&& messages)
             return;
         }
     }
+#ifdef ENABLE_PLUGIN
+    auto& pluginChatManager = Manager::instance().getJamiPluginManager().getChatServicesManager();
+    if (pluginChatManager.hasHandlers()) {
+        pluginChatManager.publishMessage(std::make_shared<JamiMessage>(getAccountId(),
+                                            getPeerNumber(),
+                                            true,
+                                            messages,
+                                            false));
+    }
+#endif
     Manager::instance().incomingMessage(getCallId(), getPeerNumber(), messages);
 }
 
@@ -415,8 +445,7 @@ Call::peerHungup()
 {
     const auto state = getState();
     const auto aborted = state == CallState::ACTIVE or state == CallState::HOLD;
-    setState(ConnectionState::DISCONNECTED,
-             aborted ? ECONNABORTED : ECONNREFUSED);
+    setState(ConnectionState::DISCONNECTED, aborted ? ECONNABORTED : ECONNREFUSED);
 }
 
 void
@@ -428,8 +457,7 @@ Call::addSubCall(Call& subcall)
     // Because we only want to addSubCall if the peer didn't answer
     // So till it's <= RINGING
     if (connectionState_ == ConnectionState::CONNECTED
-        || connectionState_ == ConnectionState::DISCONNECTED
-        || callState_ == CallState::OVER) {
+        || connectionState_ == ConnectionState::DISCONNECTED || callState_ == CallState::OVER) {
         subcall.removeCall();
         return;
     }
@@ -446,11 +474,12 @@ Call::addSubCall(Call& subcall)
         subcall.sendTextMessage(msg.first, msg.second);
 
     subcall.addStateListener(
-        [sub = subcall.weak(), parent = weak()](Call::CallState new_state, Call::ConnectionState new_cstate, int code) {
-            runOnMainThread([sub, parent, new_state, new_cstate, code]() {
+        [sub = subcall.weak(),
+         parent = weak()](Call::CallState new_state, Call::ConnectionState new_cstate, int code) {
+            runOnMainThread([sub, parent, new_state, new_cstate]() {
                 if (auto p = parent.lock()) {
                     if (auto s = sub.lock()) {
-                      p->subcallStateChanged(*s, new_state, new_cstate);
+                        p->subcallStateChanged(*s, new_state, new_cstate);
                     }
                 }
             });
@@ -463,9 +492,7 @@ Call::addSubCall(Call& subcall)
 /// Parent call states are managed by these subcalls.
 /// \note this method may decrease the given \a subcall ref count.
 void
-Call::subcallStateChanged(Call& subcall,
-                          Call::CallState new_state,
-                          Call::ConnectionState new_cstate)
+Call::subcallStateChanged(Call& subcall, Call::CallState new_state, Call::ConnectionState new_cstate)
 {
     {
         // This condition happens when a subcall hangups/fails after removed from parent's list.
@@ -480,19 +507,21 @@ Call::subcallStateChanged(Call& subcall,
 
     // We found a responding device: hangup all other subcalls and merge
     if (new_state == CallState::ACTIVE and new_cstate == ConnectionState::CONNECTED) {
-        JAMI_DBG("[call:%s] subcall %s answered by peer", getCallId().c_str(),
+        JAMI_DBG("[call:%s] subcall %s answered by peer",
+                 getCallId().c_str(),
                  subcall.getCallId().c_str());
 
-        hangupCallsIf(safePopSubcalls(), 0, [&](const Call* call){ return call != &subcall; });
+        hangupCallsIf(safePopSubcalls(), 0, [&](const Call* call) { return call != &subcall; });
         merge(subcall);
         Manager::instance().peerAnsweredCall(*this);
         return;
     }
 
-    // Hangup the call if any device hangup
-    // XXX: not sure it's what we really want
-    if (new_state == CallState::ACTIVE and new_cstate == ConnectionState::DISCONNECTED) {
-        JAMI_WARN("[call:%s] subcall %s hangup by peer", getCallId().c_str(),
+    // Hangup the call if any device hangup or send busy
+    if ((new_state == CallState::ACTIVE or new_state == CallState::PEER_BUSY)
+        and new_cstate == ConnectionState::DISCONNECTED) {
+        JAMI_WARN("[call:%s] subcall %s hangup by peer",
+                  getCallId().c_str(),
                   subcall.getCallId().c_str());
 
         hangupCalls(safePopSubcalls(), 0);
@@ -506,20 +535,28 @@ Call::subcallStateChanged(Call& subcall,
         if (new_state == CallState::BUSY || new_state == CallState::PEER_BUSY)
             JAMI_WARN("[call:%s] subcall %s busy", getCallId().c_str(), subcall.getCallId().c_str());
         else
-            JAMI_WARN("[call:%s] subcall %s failed", getCallId().c_str(), subcall.getCallId().c_str());
+            JAMI_WARN("[call:%s] subcall %s failed",
+                      getCallId().c_str(),
+                      subcall.getCallId().c_str());
         std::lock_guard<std::recursive_mutex> lk {callMutex_};
         subcalls_.erase(getPtr(subcall));
 
         // Parent call fails if last subcall is busy or failed
         if (subcalls_.empty()) {
             if (new_state == CallState::BUSY) {
-                setState(CallState::BUSY, ConnectionState::DISCONNECTED, static_cast<int>(std::errc::device_or_resource_busy));
+                setState(CallState::BUSY,
+                         ConnectionState::DISCONNECTED,
+                         static_cast<int>(std::errc::device_or_resource_busy));
             } else if (new_state == CallState::PEER_BUSY) {
-                setState(CallState::PEER_BUSY, ConnectionState::DISCONNECTED, static_cast<int>(std::errc::device_or_resource_busy));
+                setState(CallState::PEER_BUSY,
+                         ConnectionState::DISCONNECTED,
+                         static_cast<int>(std::errc::device_or_resource_busy));
             } else {
-                // XXX: first idea was to use std::errc::host_unreachable, but it's not available on some platforms
-                // like mingw.
-                setState(CallState::MERROR, ConnectionState::DISCONNECTED, static_cast<int>(std::errc::io_error));
+                // XXX: first idea was to use std::errc::host_unreachable, but it's not available on
+                // some platforms like mingw.
+                setState(CallState::MERROR,
+                         ConnectionState::DISCONNECTED,
+                         static_cast<int>(std::errc::io_error));
             }
             removeCall();
         } else {
@@ -577,7 +614,7 @@ Call::checkPendingIM()
             pendingInMessages_.clear();
 
             std::weak_ptr<Call> callWkPtr = shared_from_this();
-            runOnMainThread([callWkPtr, pending = std::move(pendingOutMessages_)]{
+            runOnMainThread([callWkPtr, pending = std::move(pendingOutMessages_)] {
                 if (auto call = callWkPtr.lock())
                     for (const auto& msg : pending)
                         call->sendTextMessage(msg.first, msg.second);
@@ -621,23 +658,83 @@ Call::setConferenceInfo(const std::string& msg)
     Json::CharReaderBuilder rbuilder;
     auto reader = std::unique_ptr<Json::CharReader>(rbuilder.newCharReader());
     if (reader->parse(msg.data(), msg.data() + msg.size(), &json, &err)) {
-        for (const auto& participantInfo: json) {
-            ParticipantInfo pInfo;
-            if (!participantInfo.isMember("uri")) continue;
-            pInfo.fromJson(participantInfo);
-            newInfo.emplace_back(pInfo);
+        if (json.isObject()) {
+            // new confInfo
+            if (json.isMember("p")) {
+                for (const auto& participantInfo : json["p"]) {
+                    ParticipantInfo pInfo;
+                    if (!participantInfo.isMember("uri"))
+                        continue;
+                    pInfo.fromJson(participantInfo);
+                    newInfo.emplace_back(pInfo);
+                }
+            }
+            if (json.isMember("w"))
+                newInfo.w = json["w"].asInt();
+            if (json.isMember("h"))
+                newInfo.h = json["h"].asInt();
+        } else {
+            // old confInfo
+            for (const auto& participantInfo : json) {
+                ParticipantInfo pInfo;
+                if (!participantInfo.isMember("uri"))
+                    continue;
+                pInfo.fromJson(participantInfo);
+                newInfo.emplace_back(pInfo);
+            }
         }
     }
 
-    std::vector<std::map<std::string, std::string>> toSend;
     {
         std::lock_guard<std::mutex> lk(confInfoMutex_);
-        confInfo_ = std::move(newInfo);
-        toSend = confInfo_.toVectorMapStringString();
+        if (confID_.empty()) {
+            // confID_ empty -> participant set confInfo with the received one
+            confInfo_ = std::move(newInfo);
+            // Create sink for each participant
+            createSinks(confInfo_);
+            // Inform client that layout has changed
+            jami::emitSignal<DRing::CallSignal::OnConferenceInfosUpdated>(
+                id_, confInfo_.toVectorMapStringString());
+        } else if (auto conf = Manager::instance().getConferenceFromID(confID_)) {
+            conf->mergeConfInfo(newInfo, getPeerNumber());
+        }
     }
+}
 
-    // Inform client that layout has changed
-    jami::emitSignal<DRing::CallSignal::OnConferenceInfosUpdated>(id_, std::move(toSend));
+void
+Call::sendConfOrder(const Json::Value& root)
+{
+    std::map<std::string, std::string> messages;
+    Json::StreamWriterBuilder wbuilder;
+    wbuilder["commentStyle"] = "None";
+    wbuilder["indentation"] = "";
+    messages["application/confOrder+json"] = Json::writeString(wbuilder, root);
+
+    auto w = getAccount();
+    auto account = w.lock();
+    if (account)
+        sendTextMessage(messages, account->getFromUri());
+}
+
+void
+Call::sendConfInfo(const std::string& json)
+{
+    std::map<std::string, std::string> messages;
+    Json::StreamWriterBuilder wbuilder;
+    wbuilder["commentStyle"] = "None";
+    wbuilder["indentation"] = "";
+    messages["application/confInfo+json"] = json;
+
+    auto w = getAccount();
+    auto account = w.lock();
+    if (account)
+        sendTextMessage(messages, account->getFromUri());
+}
+
+void
+Call::resetConfInfo()
+{
+    sendConfInfo("{}");
 }
 
 } // namespace jami
