@@ -30,9 +30,11 @@
 #include "security/tls_session.h"
 #include "security/diffie-hellman.h"
 #include "sip/sipaccountbase.h"
-#include "dring/datatransfer_interface.h"
+#include "jami/datatransfer_interface.h"
 #include "jamidht/conversation.h"
 #include "multiplexed_socket.h"
+#include "data_transfer.h"
+#include "uri.h"
 
 #include "noncopyable.h"
 #include "ip_utils.h"
@@ -41,6 +43,9 @@
 #include "scheduled_executor.h"
 #include "connectionmanager.h"
 #include "gitserver.h"
+#include "channel_handler.h"
+#include "conversation_module.h"
+#include "sync_module.h"
 #include "conversationrepository.h"
 
 #include <opendht/dhtrunner.h>
@@ -50,12 +55,13 @@
 
 #include <pjsip/sip_types.h>
 
-#include <vector>
-#include <map>
 #include <chrono>
-#include <list>
 #include <future>
 #include <json/json.h>
+#include <list>
+#include <map>
+#include <optional>
+#include <vector>
 
 #if HAVE_RINGNS
 #include "namedirectory.h"
@@ -77,7 +83,6 @@ namespace jami {
 
 class IceTransport;
 struct Contact;
-struct DeviceSync;
 struct AccountArchive;
 class DhtPeerConnector;
 class ContactList;
@@ -85,9 +90,10 @@ class AccountManager;
 struct AccountInfo;
 class SipTransport;
 class ChanneledOutgoingTransfer;
+class SyncModule;
 
 using SipConnectionKey = std::pair<std::string /* accountId */, DeviceId>;
-using GitSocketList = std::map<std::string,                            /* device Id */
+using GitSocketList = std::map<DeviceId,                               /* device Id */
                                std::map<std::string,                   /* conversation */
                                         std::shared_ptr<ChannelSocket> /* related socket */
                                         >>;
@@ -108,6 +114,8 @@ public:
         = "https://config.jami.net/proxyList";
 
     /* constexpr */ static const std::pair<uint16_t, uint16_t> DHT_PORT_RANGE;
+    constexpr static int ICE_STREAMS_COUNT {1};
+    constexpr static int ICE_COMP_COUNT_PER_STREAM {1};
 
     const char* getAccountType() const override { return ACCOUNT_TYPE; }
 
@@ -235,6 +243,12 @@ public:
      */
     std::string getServerUri() const { return ""; };
 
+    void setIsComposing(const std::string& conversationUri, bool isWriting) override;
+
+    bool setMessageDisplayed(const std::string& conversationUri,
+                             const std::string& messageId,
+                             int status) override;
+
     /**
      * Get the contact header for
      * @return pj_str_t The contact header based on account information
@@ -262,32 +276,29 @@ public:
      * @return A shared pointer on the created call.
      */
     std::shared_ptr<Call> newOutgoingCall(std::string_view toUrl,
-                                          const std::vector<MediaAttribute>& mediaList) override;
+                                          const std::vector<DRing::MediaMap>& mediaList) override;
 
     /**
      * Create incoming SIPCall.
      * @param[in] from The origin of the call
-     * @param details Call details
+     * @param mediaList A list of media
      * @param sipTr: SIP Transport
      * @return A shared pointer on the created call.
      */
     std::shared_ptr<SIPCall> newIncomingCall(
         const std::string& from,
-        const std::map<std::string, std::string>& details = {},
-        const std::shared_ptr<SipTransport>& sipTr = nullptr) override;
+        const std::vector<DRing::MediaMap>& mediaList,
+        const std::shared_ptr<SipTransport>& sipTr = {}) override;
 
     void onTextMessage(const std::string& id,
                        const std::string& from,
+                       const std::string& deviceId,
                        const std::map<std::string, std::string>& payloads) override;
 
     virtual bool isTlsEnabled() const override { return true; }
 
-    virtual bool isSrtpEnabled() const { return true; }
-
-    virtual KeyExchangeProtocol getSrtpKeyExchange() const override
-    {
-        return KeyExchangeProtocol::SDES;
-    }
+    bool isSrtpEnabled() const override { return true; }
+    KeyExchangeProtocol getSrtpKeyExchange() const { return KeyExchangeProtocol::SDES; }
 
     virtual bool getSrtpFallback() const override { return false; }
 
@@ -298,10 +309,14 @@ public:
     bool findCertificate(
         const dht::InfoHash& h,
         std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb = {});
+    bool findCertificate(
+        const dht::PkId& h,
+        std::function<void(const std::shared_ptr<dht::crypto::Certificate>&)>&& cb = {});
 
     /* contact requests */
     std::vector<std::map<std::string, std::string>> getTrustRequests() const;
-    bool acceptTrustRequest(const std::string& from);
+    // Note: includeConversation used for compatibility test. Do not change
+    bool acceptTrustRequest(const std::string& from, bool includeConversation = true);
     bool discardTrustRequest(const std::string& from);
 
     /**
@@ -312,6 +327,17 @@ public:
     void removeContact(const std::string& uri, bool banned = true);
     std::vector<std::map<std::string, std::string>> getContacts() const;
 
+    /**
+     * Replace in contact's details related conversation
+     * @param uri           Of the contact
+     * @param oldConv       Current conversation
+     * @param newConv
+     * @return if replaced
+     */
+    bool updateConvForContact(const std::string& uri,
+                              const std::string& oldConv,
+                              const std::string& newConv);
+
     ///
     /// Obtain details about one account contact in serializable form.
     ///
@@ -321,10 +347,13 @@ public:
     void sendTextMessage(const std::string& to,
                          const std::map<std::string, std::string>& payloads,
                          uint64_t id,
-                         bool retryOnTimeout = true) override;
+                         bool retryOnTimeout = true,
+                         bool onlyConnected = false) override;
     uint64_t sendTextMessage(const std::string& to,
                              const std::map<std::string, std::string>& payloads) override;
-    void onIsComposing(const std::string& peer, bool isWriting) override;
+    void sendInstantMessage(const std::string& convId,
+                            const std::map<std::string, std::string>& msg);
+    void onIsComposing(const std::string& conversationId, const std::string& peer, bool isWriting);
 
     /* Devices */
     void addDevice(const std::string& password);
@@ -355,14 +384,16 @@ public:
 #endif
     bool searchUser(const std::string& nameQuery);
 
-    ///
-    /// Send a E2E connection request to a given peer for the given transfer id
-    ///
-    /// /// \param[in] peer RingID on request's recipient
-    /// /// \param[in] tid linked outgoing data transfer
-    ///
-    void requestPeerConnection(
-        const std::string& peer,
+    /**
+     * Send a E2E connection request to a given peer for the given transfer id
+     * @param peer RingID on request's recipient
+     * @param tid linked outgoing data transfer
+     * @param isVcard if transfer is a vcard transfer
+     * @param channeledConnectedCb callback when channel is connected
+     * @param onChanneledCancelled callback when channel is canceled
+     */
+    void requestConnection(
+        const DRing::DataTransferInfo& info,
         const DRing::DataTransferId& tid,
         bool isVCard,
         const std::function<void(const std::shared_ptr<ChanneledOutgoingTransfer>&)>&
@@ -380,7 +411,7 @@ public:
     /// \return true if the given DHT message identifier has been treated
     /// \note if message has not been treated yet this method store this id and returns true at
     /// further calls
-    bool isMessageTreated(const std::string& id);
+    bool isMessageTreated(std::string_view id);
 
     std::shared_ptr<dht::DhtRunner> dht() { return dht_; }
 
@@ -389,7 +420,7 @@ public:
     const std::shared_future<tls::DhParams> dhParams() const { return dhParams_; }
 
     void forEachDevice(const dht::InfoHash& to,
-                       std::function<void(const dht::InfoHash&)>&& op,
+                       std::function<void(const std::shared_ptr<dht::crypto::PublicKey>&)>&& op,
                        std::function<void(bool)>&& end = {});
 
     /**
@@ -399,7 +430,7 @@ public:
      */
     void enableProxyClient(bool enable);
 
-    void setPushNotificationToken(const std::string& pushDeviceToken = "");
+    void setPushNotificationToken(const std::string& pushDeviceToken = "") override;
 
     /**
      * To be called by clients with relevant data when a push notification is received.
@@ -440,10 +471,16 @@ public:
     /**
      * Create and return ICE options.
      */
-    void getIceOptions(std::function<void(IceTransportOptions)> cb) noexcept;
+    void getIceOptions(std::function<void(IceTransportOptions&&)> cb) noexcept;
 
 #ifdef DRING_TESTABLE
     ConnectionManager& connectionManager() { return *connectionManager_; }
+
+    /**
+     * Only used for tests, disable sha3sum verification for transfers.
+     * @param newValue
+     */
+    void noSha3sumVerification(bool newValue) { noSha3sumVerification_ = newValue; }
 #endif
 
     /**
@@ -451,21 +488,25 @@ public:
      * ConnectionManager needs the account to exists
      */
     void shutdownConnections();
-    std::shared_ptr<ChannelSocket> gitSocket(const std::string& deviceId,
-                                             const std::string& conversationId) const
+    std::optional<std::weak_ptr<ChannelSocket>> gitSocket(const DeviceId& deviceId,
+                                                          const std::string& conversationId) const
     {
         auto deviceSockets = gitSocketList_.find(deviceId);
         if (deviceSockets == gitSocketList_.end()) {
-            return nullptr;
+            return std::nullopt;
         }
         auto socketIt = deviceSockets->second.find(conversationId);
         if (socketIt == deviceSockets->second.end()) {
-            return nullptr;
+            return std::nullopt;
         }
         return socketIt->second;
     }
+    bool hasGitSocket(const DeviceId& deviceId, const std::string& conversationId) const
+    {
+        return gitSocket(deviceId, conversationId) != std::nullopt;
+    }
 
-    void addGitSocket(const std::string& deviceId,
+    void addGitSocket(const DeviceId& deviceId,
                       const std::string& conversationId,
                       const std::shared_ptr<ChannelSocket>& socket)
     {
@@ -473,7 +514,7 @@ public:
         deviceSockets[conversationId] = socket;
     }
 
-    void removeGitSocket(const std::string& deviceId, const std::string& conversationId)
+    void removeGitSocket(const DeviceId& deviceId, const std::string& conversationId)
     {
         auto deviceSockets = gitSocketList_.find(deviceId);
         if (deviceSockets == gitSocketList_.end()) {
@@ -486,82 +527,68 @@ public:
     }
 
     std::string_view currentDeviceId() const;
-    // Conversation management
-    std::string startConversation(ConversationMode mode = ConversationMode::INVITES_ONLY,
-                                  const std::string& otherMember = "");
-    void acceptConversationRequest(const std::string& conversationId);
-    void declineConversationRequest(const std::string& conversationId);
-    std::vector<std::string> getConversations();
-    bool removeConversation(const std::string& conversationId);
-    std::vector<std::map<std::string, std::string>> getConversationRequests();
-
-    // Conversation's infos management
-    void updateConversationInfos(const std::string& conversationId,
-                                 const std::map<std::string, std::string>& infos,
-                                 bool sync = true);
-    std::map<std::string, std::string> conversationInfos(const std::string& conversationId) const;
-    std::vector<uint8_t> conversationVCard(const std::string& conversationId) const;
 
     // Member management
-    bool addConversationMember(const std::string& conversationId,
-                               const std::string& contactUri,
-                               bool sendRequest = true);
-    bool removeConversationMember(const std::string& conversationId,
-                                  const std::string& contactUri,
-                                  bool isDevice = false);
-    std::vector<std::map<std::string, std::string>> getConversationMembers(
-        const std::string& conversationId) const;
-
-    // Message send/load
-    void sendMessage(const std::string& conversationId,
-                     const Json::Value& value,
-                     const std::string& parent = "",
-                     bool announce = true);
-    void sendMessage(const std::string& conversationId,
-                     const std::string& message,
-                     const std::string& parent = "",
-                     const std::string& type = "text/plain",
-                     bool announce = true);
-    /**
-     * Add to the related conversation the call history message
-     * @param uri           Peer number
-     * @param duration_ms   The call duration in ms
-     */
-    void addCallHistoryMessage(const std::string& uri, uint64_t duration_ms);
-    uint32_t loadConversationMessages(const std::string& conversationId,
-                                      const std::string& fromMessage = "",
-                                      size_t n = 0);
+    void saveMembers(const std::string& convId,
+                     const std::vector<std::string>& members); // Save confInfos
 
     // Received a new commit notification
-    void onNewGitCommit(const std::string& peer,
-                        const std::string& deviceId,
-                        const std::string& conversationId,
-                        const std::string& commitId) override;
-    /**
-     * Pull remote device (do not do it if commitId is already in the current repo)
-     * @param peer              Contact URI
-     * @param deviceId          Contact's device
-     * @param conversationId
-     * @param commitId (optional)
-     */
-    void fetchNewCommits(const std::string& peer,
-                         const std::string& deviceId,
-                         const std::string& conversationId,
-                         const std::string& commitId = "");
 
-    // Invites
-    void onConversationRequest(const std::string& from, const Json::Value&) override;
-    void onNeedConversationRequest(const std::string& from,
-                                   const std::string& conversationId) override;
+    bool handleMessage(const std::string& from,
+                       const std::pair<std::string, std::string>& message) override;
 
     void monitor() const;
 
+    // File transfer
+    void sendFile(const std::string& conversationId,
+                  const std::string& path,
+                  const std::string& name,
+                  const std::string& parent);
+
+    // non-swarm version
+    DRing::DataTransferId sendFile(const std::string& peer,
+                                   const std::string& path,
+                                   const InternalCompletionCb& icb = {});
+
+    void transferFile(const std::string& conversationId,
+                      const std::string& path,
+                      const std::string& deviceId,
+                      const std::string& fileId,
+                      const std::string& interactionId,
+                      size_t start = 0,
+                      size_t end = 0);
+
+    void askForFileChannel(const std::string& conversationId,
+                           const std::string& deviceId,
+                           const std::string& fileId,
+                           size_t start = 0,
+                           size_t end = 0);
+
     /**
-     * Clone a conversation (initial) from device
-     * @param deviceId
-     * @param convId
+     * Retrieve linked transfer manager
+     * @param id    conversationId or empty for fallback
+     * @return linked transfer manager
      */
-    void cloneConversation(const std::string& deviceId, const std::string& convId);
+    std::shared_ptr<TransferManager> dataTransfer(const std::string& id = "");
+
+    ConversationModule* convModule();
+    SyncModule* syncModule();
+
+    /**
+     * Send Profile via cached SIP connection
+     * @param deviceId      Device that will receive the profile
+     */
+    // Note: when swarm will be merged, this can be moved in transferManager
+    bool needToSendProfile(const std::string& deviceId);
+    /**
+     * Send Profile via cached SIP connection
+     * @param deviceId      Device that will receive the profile
+     */
+    void sendProfile(const std::string& deviceId);
+
+    std::string profilePath() const;
+
+    AccountManager* accountManager() { return accountManager_.get(); }
 
 private:
     NON_COPYABLE(JamiAccount);
@@ -573,7 +600,6 @@ private:
      * Private structures
      */
     struct PendingCall;
-    struct PendingConversationFetch;
     struct PendingMessage;
     struct BuddyInfo;
     struct DiscoveredPeer;
@@ -588,9 +614,6 @@ private:
     void trackPresence(const dht::InfoHash& h, BuddyInfo& buddy);
 
     void doRegister_();
-    void incomingCall(dht::IceCandidates&& msg,
-                      const std::shared_ptr<dht::crypto::Certificate>& from_cert,
-                      const dht::InfoHash& from);
 
     const dht::ValueType USER_PROFILE_TYPE = {9, "User profile", std::chrono::hours(24 * 7)};
 
@@ -612,7 +635,7 @@ private:
      * @param call  The current call
      * @return true if all is correct
      */
-    bool SIPStartCall(SIPCall& call, IpAddr target);
+    bool SIPStartCall(SIPCall& call, const IpAddr& target);
 
     /**
      * For a call with (from_device, from_account), check the peer certificate chain (cert_list,
@@ -643,9 +666,6 @@ private:
      * Add port mapping callback function.
      */
     void onPortMappingAdded(uint16_t port_used, bool success);
-
-    void checkPendingCall(const std::string& callId);
-    bool handlePendingCall(PendingCall& pc, bool incoming);
     void forEachPendingCall(const DeviceId& deviceId,
                             const std::function<void(const std::shared_ptr<SIPCall>&)>& cb);
 
@@ -675,9 +695,6 @@ private:
                                                             const std::string& path,
                                                             const std::string& name);
 
-    void loadTreatedCalls();
-    void saveTreatedCalls() const;
-
     void loadTreatedMessages();
     void saveTreatedMessages() const;
 
@@ -703,12 +720,6 @@ private:
      */
     void generateDhParams();
 
-    void loadConvInfos();
-    void saveConvInfos() const;
-
-    void loadConvRequests();
-    void saveConvRequests();
-
     template<class... Args>
     std::shared_ptr<IceTransport> createIceTransport(const Args&... args);
     void newOutgoingCallHelper(const std::shared_ptr<SIPCall>& call, std::string_view toUri);
@@ -724,25 +735,11 @@ private:
     std::unique_ptr<AccountManager> accountManager_;
     dht::crypto::Identity id_ {};
 
-    dht::InfoHash callKey_;
-
-    /**
-     * DHT calls waiting for ICE negotiation
-     */
-    std::map<std::string, PendingCall> pendingCallsDht_;
-
-    /**
-     * Incoming DHT calls that are not yet actual SIP calls.
-     */
-    std::list<PendingCall> pendingSipCalls_;
-    std::set<dht::Value::Id> treatedCalls_ {};
-    mutable std::mutex callsMutex_ {};
-
     mutable std::mutex messageMutex_ {};
     std::map<dht::Value::Id, PendingMessage> sentMessages_;
-    std::set<std::string> treatedMessages_ {};
+    std::set<std::string, std::less<>> treatedMessages_ {};
 
-    std::string ringDeviceName_ {};
+    std::string deviceName_ {};
     std::string idPath_ {};
     std::string cachePath_ {};
     std::string dataPath_ {};
@@ -757,16 +754,6 @@ private:
     mutable std::mutex buddyInfoMtx;
     std::map<dht::InfoHash, BuddyInfo> trackedBuddies_;
 
-    /** Conversations */
-    mutable std::mutex conversationsMtx_ {};
-    std::map<std::string, std::shared_ptr<Conversation>> conversations_;
-    bool isConversation(const std::string& convId) const
-    {
-        std::lock_guard<std::mutex> lk(conversationsMtx_);
-        return conversations_.find(convId) != conversations_.end();
-    }
-    mutable std::vector<ConvInfo> convInfos_;
-
     mutable std::mutex dhtValuesMtx_;
     bool dhtPublicInCalls_ {true};
 
@@ -800,7 +787,6 @@ private:
     bool proxyEnabled_ {false};
     std::string proxyServer_ {};
     std::string proxyServerCached_ {};
-    std::string deviceKey_ {};
 
     std::mutex dhParamsMtx_ {};
     std::shared_future<tls::DhParams> dhParams_;
@@ -874,11 +860,6 @@ private:
      */
     void callConnectionClosed(const DeviceId& deviceId, bool eraseDummy);
 
-    // Sync connections
-    std::mutex syncConnectionsMtx_;
-    std::map<std::string /* deviceId */, std::vector<std::shared_ptr<ChannelSocket>>>
-        syncConnections_;
-
     /**
      * Ask a device to open a channeled SIP socket
      * @param peerId        The contact who owns the device
@@ -905,16 +886,6 @@ private:
                                const std::string& peerId,
                                const DeviceId& deviceId);
 
-    /**
-     * Store a new Sync connection
-     * @param socket    The new sync channel
-     * @param peerId    The contact who owns the device
-     * @param deviceId  Device linked to that transport
-     */
-    void cacheSyncConnection(std::shared_ptr<ChannelSocket>&& socket,
-                             const std::string& peerId,
-                             const DeviceId& deviceId);
-
     // File transfers
     std::mutex transfersMtx_ {};
     std::set<std::string> incomingFileTransfers_ {};
@@ -937,62 +908,24 @@ private:
                         const std::map<std::string, std::string>& data,
                         pjsip_endpt_send_callback cb);
 
-    /**
-     * Send Profile via cached SIP connection
-     * @param deviceId      Device that will receive the profile
-     */
-    bool needToSendProfile(const std::string& deviceId);
-    /**
-     * Send Profile via cached SIP connection
-     * @param deviceId      Device that will receive the profile
-     */
-    void sendProfile(const std::string& deviceId);
-
-    // Conversations
-    std::mutex conversationsRequestsMtx_ {};
-    std::map<std::string, ConversationRequest> conversationsRequests_ {};
-    std::mutex pendingConversationsFetchMtx_ {};
-    std::map<std::string, PendingConversationFetch> pendingConversationsFetch_;
-
     std::mutex gitServersMtx_ {};
     std::map<dht::Value::Id, std::unique_ptr<GitServer>> gitServers_ {};
 
-    std::shared_ptr<RepeatedTask> conversationsEventHandler {};
-    void checkConversationsEvents();
-    bool handlePendingConversations();
+    std::atomic_bool deviceAnnounced_ {false};
 
-    void syncWith(const std::string& deviceId, const std::shared_ptr<ChannelSocket>& socket);
-    void syncInfos(const std::shared_ptr<ChannelSocket>& socket);
-    void syncWithConnected();
-    std::atomic_bool needsConvSync_ {true};
+    //// File transfer
+    std::shared_ptr<TransferManager> nonSwarmTransferManager_;
+    std::mutex transferMutex_ {};
+    std::map<std::string, std::shared_ptr<TransferManager>> transferManagers_ {};
 
-    /**
-     * Remove a repository and all files
-     * @param convId
-     * @param sync      If we send an update to other account's devices
-     * @param force     True if ignore the removing flag
-     */
-    void removeRepository(const std::string& convId, bool sync, bool force = false);
+    bool noSha3sumVerification_ {false};
 
-    /**
-     * Send a message notification to all members
-     * @param conversation
-     * @param commit
-     * @param sync      If we send an update to other account's devices
-     */
-    void sendMessageNotification(const Conversation& conversation,
-                                 const std::string& commitId,
-                                 bool sync);
+    std::map<Uri::Scheme, std::unique_ptr<ChannelHandlerInterface>> channelHandlers_ {};
 
-    void announceMemberMessage(const std::string& convId,
-                               const std::map<std::string, std::string>& message) const;
+    std::unique_ptr<ConversationModule> convModule_;
+    std::unique_ptr<SyncModule> syncModule_;
 
-    /**
-     * Get related conversation with member
-     * @param uri       The member to search for
-     * @return the conversation id if found else empty
-     */
-    std::string getOneToOneConversation(const std::string& uri) const;
+    void initConnectionManager();
 };
 
 static inline std::ostream&
