@@ -35,7 +35,6 @@
 #include "manager.h"
 #include "logger.h"
 #include "libav_utils.h"
-#include "array_size.h"
 
 #include "media_codec.h"
 #include "system_codec_container.h"
@@ -57,18 +56,12 @@ static constexpr int POOL_INITIAL_SIZE = 16384;
 static constexpr int POOL_INCREMENT_SIZE = POOL_INITIAL_SIZE;
 
 Sdp::Sdp(const std::string& id)
-    : memPool_(nullptr,
-               [](pj_pool_t* pool) {
-                   sip_utils::register_thread();
-                   pj_pool_release(pool);
-               })
+    : memPool_(nullptr, [](pj_pool_t* pool) { pj_pool_release(pool); })
     , publishedIpAddr_()
     , publishedIpAddrType_()
-    , sdesNego_ {CryptoSuites}
     , telephoneEventPayload_(101) // same as asterisk
     , sessionName_("Call ID " + id)
 {
-    sip_utils::register_thread();
     memPool_.reset(pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory,
                                   id.c_str(),
                                   POOL_INITIAL_SIZE,
@@ -80,9 +73,9 @@ Sdp::Sdp(const std::string& id)
 
 Sdp::~Sdp()
 {
-    SIPAccount::releasePort(localAudioDataPort_);
+    SIPAccount::releasePort(localAudioRtpPort_);
 #ifdef ENABLE_VIDEO
-    SIPAccount::releasePort(localVideoDataPort_);
+    SIPAccount::releasePort(localVideoRtpPort_);
 #endif
 }
 
@@ -137,12 +130,14 @@ randomFill(std::vector<uint8_t>& dest)
 void
 Sdp::setActiveLocalSdpSession(const pjmedia_sdp_session* sdp)
 {
+    JAMI_DBG("Set active local session to [%p]. Was [%p]", sdp, activeLocalSession_);
     activeLocalSession_ = sdp;
 }
 
 void
 Sdp::setActiveRemoteSdpSession(const pjmedia_sdp_session* sdp)
 {
+    JAMI_DBG("Set active remote session to [%p]. Was [%p]", sdp, activeRemoteSession_);
     activeRemoteSession_ = sdp;
 }
 
@@ -213,8 +208,32 @@ Sdp::getMediaDirection(pjmedia_sdp_media* media)
     return MediaDirection::UNKNOWN;
 }
 
+MediaTransport
+Sdp::getMediaTransport(pjmedia_sdp_media* media)
+{
+    if (pj_stricmp2(&media->desc.transport, "RTP/SAVP") == 0)
+        return MediaTransport::RTP_SAVP;
+    else if (pj_stricmp2(&media->desc.transport, "RTP/AVP") == 0)
+        return MediaTransport::RTP_AVP;
+
+    return MediaTransport::UNKNOWN;
+}
+
+std::vector<std::string>
+Sdp::getCrypto(pjmedia_sdp_media* media)
+{
+    std::vector<std::string> crypto;
+    for (unsigned j = 0; j < media->attr_count; j++) {
+        const auto attribute = media->attr[j];
+        if (pj_stricmp2(&attribute->name, "crypto") == 0)
+            crypto.emplace_back(attribute->value.ptr, attribute->value.slen);
+    }
+
+    return crypto;
+}
+
 pjmedia_sdp_media*
-Sdp::addMediaDescription(const MediaAttribute& mediaAttr, bool onHold)
+Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
 {
     auto type = mediaAttr.type_;
     auto secure = mediaAttr.secure_;
@@ -226,12 +245,12 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr, bool onHold)
     switch (type) {
     case MediaType::MEDIA_AUDIO:
         med->desc.media = sip_utils::CONST_PJ_STR("audio");
-        med->desc.port = localAudioDataPort_;
+        med->desc.port = mediaAttr.enabled_ ? localAudioRtpPort_ : 0;
         med->desc.fmt_count = audio_codec_list_.size();
         break;
     case MediaType::MEDIA_VIDEO:
         med->desc.media = sip_utils::CONST_PJ_STR("video");
-        med->desc.port = localVideoDataPort_;
+        med->desc.port = mediaAttr.enabled_ ? localVideoRtpPort_ : 0;
         med->desc.fmt_count = video_codec_list_.size();
         break;
     default:
@@ -300,8 +319,8 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr, bool onHold)
             const auto accountVideoCodec = std::static_pointer_cast<AccountVideoCodecInfo>(
                 video_codec_list_[i]);
             const auto& profileLevelID = accountVideoCodec->parameters.empty()
-                                            ? libav_utils::DEFAULT_H264_PROFILE_LEVEL_ID
-                                            : accountVideoCodec->parameters;
+                                             ? libav_utils::DEFAULT_H264_PROFILE_LEVEL_ID
+                                             : accountVideoCodec->parameters;
             auto value = fmt::format("fmtp:{} {}", payload, profileLevelID);
             med->attr[med->attr_count++] = pjmedia_sdp_attr_create(memPool_.get(),
                                                                    value.c_str(),
@@ -312,10 +331,14 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr, bool onHold)
 
     if (type == MediaType::MEDIA_AUDIO) {
         setTelephoneEventRtpmap(med);
-        addRTCPAttribute(med); // video has its own RTCP
+        if (localAudioRtcpPort_) {
+            addRTCPAttribute(med, localAudioRtcpPort_);
+        }
+    } else if (type == MediaType::MEDIA_VIDEO and localVideoRtcpPort_) {
+        addRTCPAttribute(med, localVideoRtcpPort_);
     }
 
-    char const* direction = mediaDirection(type, onHold);
+    char const* direction = mediaDirection(type, mediaAttr.onHold_);
 
     med->attr[med->attr_count++] = pjmedia_sdp_attr_create(memPool_.get(), direction, NULL);
 
@@ -328,11 +351,11 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr, bool onHold)
 }
 
 void
-Sdp::addRTCPAttribute(pjmedia_sdp_media* med)
+Sdp::addRTCPAttribute(pjmedia_sdp_media* med, uint16_t port)
 {
-    IpAddr outputAddr {publishedIpAddr_};
-    outputAddr.setPort(localAudioControlPort_);
-    pjmedia_sdp_attr* attr = pjmedia_sdp_attr_create_rtcp(memPool_.get(), outputAddr.pjPtr());
+    IpAddr addr {publishedIpAddr_};
+    addr.setPort(port);
+    pjmedia_sdp_attr* attr = pjmedia_sdp_attr_create_rtcp(memPool_.get(), addr.pjPtr());
     if (attr)
         pjmedia_sdp_attr_add(&med->attr_count, med->attr, attr);
 }
@@ -364,7 +387,9 @@ void
 Sdp::setTelephoneEventRtpmap(pjmedia_sdp_media* med)
 {
     ++med->desc.fmt_count;
-    pj_strdup2(memPool_.get(), &med->desc.fmt[med->desc.fmt_count - 1], std::to_string(telephoneEventPayload_).c_str());
+    pj_strdup2(memPool_.get(),
+               &med->desc.fmt[med->desc.fmt_count - 1],
+               std::to_string(telephoneEventPayload_).c_str());
 
     pjmedia_sdp_attr* attr_rtpmap = static_cast<pjmedia_sdp_attr*>(
         pj_pool_zalloc(memPool_.get(), sizeof(pjmedia_sdp_attr)));
@@ -413,11 +438,20 @@ Sdp::setLocalMediaCapabilities(MediaType type,
     }
 }
 
+const char*
+Sdp::getSdpDirectionStr(SdpDirection direction)
+{
+    if (direction == SdpDirection::OFFER)
+        return "OFFER";
+    if (direction == SdpDirection::ANSWER)
+        return "ANSWER";
+    return "NONE";
+}
+
 void
-Sdp::printSession(const pjmedia_sdp_session* session, const char* header, bool isOffer)
+Sdp::printSession(const pjmedia_sdp_session* session, const char* header, SdpDirection direction)
 {
     static constexpr size_t BUF_SZ = 4095;
-    sip_utils::register_thread();
     std::unique_ptr<pj_pool_t, decltype(pj_pool_release)&>
         tmpPool_(pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory,
                                 "printSdp",
@@ -440,16 +474,17 @@ Sdp::printSession(const pjmedia_sdp_session* session, const char* header, bool i
     std::array<char, BUF_SZ + 1> buffer;
     auto size = pjmedia_sdp_print(cloned_session, buffer.data(), BUF_SZ);
     if (size < 0) {
-        JAMI_ERR("%sSDP too big for dump", header);
+        JAMI_ERR("%s SDP too big for dump", header);
         return;
     }
-    JAMI_DBG("[SDP %s] %s%.*s", isOffer ? "offer" : "answer", header, size, buffer.data());
+
+    JAMI_DBG("[SDP %s] %s\n%.*s", getSdpDirectionStr(direction), header, size, buffer.data());
 }
 
 void
-Sdp::createLocalSession(bool offer)
+Sdp::createLocalSession(SdpDirection direction)
 {
-    isOffer_ = offer;
+    sdpDirection_ = direction;
     localSession_ = PJ_POOL_ZALLOC_T(memPool_.get(), pjmedia_sdp_session);
     localSession_->conn = PJ_POOL_ZALLOC_T(memPool_.get(), pjmedia_sdp_conn);
 
@@ -496,9 +531,9 @@ Sdp::createOffer(const std::vector<MediaAttribute>& mediaList)
         throw SdpException("Media list size exceeds SDP media maximum size");
     }
 
-    JAMI_DBG("Creating SDP offer with %lu medias", mediaList.size());
+    JAMI_DBG("Creating SDP offer with %lu media", mediaList.size());
 
-    createLocalSession(true);
+    createLocalSession(SdpDirection::OFFER);
 
     if (validateSession() != PJ_SUCCESS) {
         JAMI_ERR("Failed to create initial offer");
@@ -508,7 +543,9 @@ Sdp::createOffer(const std::vector<MediaAttribute>& mediaList)
     localSession_->media_count = 0;
 
     for (auto const& media : mediaList) {
-        localSession_->media[localSession_->media_count++] = addMediaDescription(media);
+        if (media.enabled_) {
+            localSession_->media[localSession_->media_count++] = addMediaDescription(media);
+        }
     }
 
     if (validateSession() != PJ_SUCCESS) {
@@ -522,59 +559,76 @@ Sdp::createOffer(const std::vector<MediaAttribute>& mediaList)
         return false;
     }
 
+    printSession(localSession_, "Local session (initial):", sdpDirection_);
+
     return true;
 }
 
 void
-Sdp::receiveOffer(const pjmedia_sdp_session* remote, const std::vector<MediaAttribute>& mediaList)
+Sdp::setReceivedOffer(const pjmedia_sdp_session* remote)
 {
     if (remote == nullptr) {
         JAMI_ERR("Remote session is NULL");
         return;
     }
+    remoteSession_ = pjmedia_sdp_session_clone(memPool_.get(), remote);
+}
 
-    JAMI_DBG("Creating SDP answer with %lu media", mediaList.size());
+bool
+Sdp::processIncomingOffer(const std::vector<MediaAttribute>& mediaList)
+{
+    if (not remoteSession_)
+        return false;
 
-    printSession(remote, "Remote session:\n", isOffer_);
+    JAMI_DBG("Processing received offer for [%s] with %lu media",
+             sessionName_.c_str(),
+             mediaList.size());
+
+    printSession(remoteSession_, "Remote session:", SdpDirection::OFFER);
 
     if (not localSession_) {
-        createLocalSession(false);
+        createLocalSession(SdpDirection::ANSWER);
         if (validateSession() != PJ_SUCCESS) {
-            JAMI_ERR("Failed to create initial offer");
-            return;
+            JAMI_ERR("Failed to create local session");
+            return false;
         }
     }
 
     localSession_->media_count = 0;
 
     for (auto const& media : mediaList) {
-        localSession_->media[localSession_->media_count++] = addMediaDescription(media);
+        if (media.enabled_) {
+            localSession_->media[localSession_->media_count++] = addMediaDescription(media);
+        }
     }
 
-    printSession(localSession_, "Local session:\n", not isOffer_);
+    printSession(localSession_, "Local session:\n", sdpDirection_);
 
     if (validateSession() != PJ_SUCCESS) {
         JAMI_ERR("Failed to add medias");
-        return;
+        return false;
     }
 
-    remoteSession_ = pjmedia_sdp_session_clone(memPool_.get(), remote);
-
     if (pjmedia_sdp_neg_create_w_remote_offer(memPool_.get(),
                                               localSession_,
                                               remoteSession_,
                                               &negotiator_)
         != PJ_SUCCESS) {
         JAMI_ERR("Failed to initialize media negotiation");
+        return false;
     }
+
+    return true;
 }
 
-void
+bool
 Sdp::startNegotiation()
 {
+    JAMI_DBG("Starting media negotiation for [%s]", sessionName_.c_str());
+
     if (negotiator_ == NULL) {
         JAMI_ERR("Can't start negotiation with invalid negotiator");
-        return;
+        return false;
     }
 
     const pjmedia_sdp_session* active_local;
@@ -582,35 +636,39 @@ Sdp::startNegotiation()
 
     if (pjmedia_sdp_neg_get_state(negotiator_) != PJMEDIA_SDP_NEG_STATE_WAIT_NEGO) {
         JAMI_WARN("Negotiator not in right state for negotiation");
-        return;
+        return false;
     }
 
-    if (pjmedia_sdp_neg_negotiate(memPool_.get(), negotiator_, 0) != PJ_SUCCESS)
-        return;
+    if (pjmedia_sdp_neg_negotiate(memPool_.get(), negotiator_, 0) != PJ_SUCCESS) {
+        JAMI_ERR("Failed to start media negotiation");
+        return false;
+    }
 
     if (pjmedia_sdp_neg_get_active_local(negotiator_, &active_local) != PJ_SUCCESS)
         JAMI_ERR("Could not retrieve local active session");
-    else {
-        setActiveLocalSdpSession(active_local);
-        if (active_local != nullptr) {
-            Sdp::printSession(active_local, "Local session:\n", isOffer_);
-        }
+
+    setActiveLocalSdpSession(active_local);
+
+    if (active_local != nullptr) {
+        printSession(active_local, "Local active session:", sdpDirection_);
     }
 
-    if (pjmedia_sdp_neg_get_active_remote(negotiator_, &active_remote) != PJ_SUCCESS)
+    if (pjmedia_sdp_neg_get_active_remote(negotiator_, &active_remote) != PJ_SUCCESS
+        or active_remote == nullptr) {
         JAMI_ERR("Could not retrieve remote active session");
-    else {
-        setActiveRemoteSdpSession(active_remote);
-        if (active_remote != nullptr) {
-            Sdp::printSession(active_remote, "Remote active session:\n", not isOffer_);
-        }
+        return false;
     }
+
+    setActiveRemoteSdpSession(active_remote);
+
+    printSession(active_remote, "Remote active session:", sdpDirection_);
+
+    return true;
 }
 
 std::string
 Sdp::getFilteredSdp(const pjmedia_sdp_session* session, unsigned media_keep, unsigned pt_keep)
 {
-    sip_utils::register_thread();
     static constexpr size_t BUF_SZ = 4096;
     std::unique_ptr<pj_pool_t, decltype(pj_pool_release)&>
         tmpPool_(pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory,
@@ -799,7 +857,7 @@ Sdp::getMediaDescriptions(const pjmedia_sdp_session* session, bool remote) const
             if (pj_stricmp2(&attribute->name, "crypto") == 0)
                 crypto.emplace_back(attribute->value.ptr, attribute->value.slen);
         }
-        descr.crypto = sdesNego_.negotiate(crypto);
+        descr.crypto = SdesNegotiator::negotiate(crypto);
     }
     return ret;
 }
@@ -840,9 +898,9 @@ Sdp::addIceCandidates(unsigned media_index, const std::vector<std::string>& cand
 std::vector<std::string>
 Sdp::getIceCandidates(unsigned media_index) const
 {
-    auto session = activeRemoteSession_ ? activeRemoteSession_ : remoteSession_;
+    auto remoteSession = activeRemoteSession_ ? activeRemoteSession_ : remoteSession_;
     auto localSession = activeLocalSession_ ? activeLocalSession_ : localSession_;
-    if (not session) {
+    if (not remoteSession) {
         JAMI_ERR("getIceCandidates failed: no remote session");
         return {};
     }
@@ -850,12 +908,12 @@ Sdp::getIceCandidates(unsigned media_index) const
         JAMI_ERR("getIceCandidates failed: no local session");
         return {};
     }
-    if (media_index >= session->media_count || media_index >= localSession->media_count) {
+    if (media_index >= remoteSession->media_count || media_index >= localSession->media_count) {
         JAMI_ERR("getIceCandidates failed: cannot access media#%u (may be deactivated)",
                  media_index);
         return {};
     }
-    auto media = session->media[media_index];
+    auto media = remoteSession->media[media_index];
     auto localMedia = localSession->media[media_index];
     if (media->desc.port == 0 || localMedia->desc.port == 0) {
         JAMI_WARN("Media#%u is disabled. Media ports: local %u, remote %u",
@@ -929,6 +987,7 @@ Sdp::clearIce(pjmedia_sdp_session* session)
         return;
     pjmedia_sdp_attr_remove_all(&session->attr_count, session->attr, "ice-ufrag");
     pjmedia_sdp_attr_remove_all(&session->attr_count, session->attr, "ice-pwd");
+    // TODO. Why this? we should not have "candidate" attribute at session level.
     pjmedia_sdp_attr_remove_all(&session->attr_count, session->attr, "candidate");
     for (unsigned i = 0; i < session->media_count; i++) {
         auto media = session->media[i];
@@ -936,4 +995,61 @@ Sdp::clearIce(pjmedia_sdp_session* session)
     }
 }
 
+std::vector<MediaAttribute>
+Sdp::getMediaAttributeListFromSdp(const pjmedia_sdp_session* sdpSession)
+{
+    if (sdpSession == nullptr) {
+        return {};
+    }
+
+    std::vector<MediaAttribute> mediaList;
+    for (unsigned idx = 0; idx < sdpSession->media_count; idx++) {
+        unsigned audioIdx = 0;
+        unsigned videoIdx = 0;
+
+        mediaList.emplace_back(MediaAttribute {});
+        auto& mediaAttr = mediaList.back();
+
+        auto const& media = sdpSession->media[idx];
+
+        // Get media type.
+        if (!pj_stricmp2(&media->desc.media, "audio"))
+            mediaAttr.type_ = MediaType::MEDIA_AUDIO;
+        else if (!pj_stricmp2(&media->desc.media, "video"))
+            mediaAttr.type_ = MediaType::MEDIA_VIDEO;
+        else {
+            JAMI_WARN("Media#%u only 'audio' and 'video' types are supported!", idx);
+            // Disable the media. No need to parse the attributes.
+            mediaAttr.enabled_ = false;
+            continue;
+        }
+
+        // Set enabled flag
+        mediaAttr.enabled_ = media->desc.port > 0;
+
+        // Get mute state.
+        auto direction = getMediaDirection(media);
+        mediaAttr.muted_ = direction != MediaDirection::SENDRECV
+                           and direction != MediaDirection::SENDONLY;
+
+        // Get transport.
+        auto transp = getMediaTransport(media);
+        if (transp == MediaTransport::UNKNOWN) {
+            JAMI_WARN("Media#%u could not determine transport type!", idx);
+        }
+
+        // A media is secure if the transport is of type RTP/SAVP
+        // and the crypto materials are present.
+        mediaAttr.secure_ = transp == MediaTransport::RTP_SAVP and not getCrypto(media).empty();
+
+        if (mediaAttr.type_ == MediaType::MEDIA_AUDIO) {
+            mediaAttr.label_ = "audio_" + std::to_string(audioIdx++);
+        } else if (mediaAttr.type_ == MediaType::MEDIA_VIDEO) {
+            mediaAttr.label_ = "video_" + std::to_string(videoIdx++);
+        }
+    }
+
+    return mediaList;
+}
+
 } // namespace jami
