@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2020 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2021 Savoir-faire Linux Inc.
  *
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Yun Liu <yun.liu@savoirfairelinux.com>
@@ -47,7 +47,6 @@
 
 #include "pres_sub_server.h"
 
-#include "array_size.h"
 #include "ip_utils.h"
 #include "sip_utils.h"
 #include "string_utils.h"
@@ -61,6 +60,11 @@
 #include <pjsip-simple/presence.h>
 #include <pjsip-simple/publish.h>
 
+// Only PJSIP 2.10 is supported.
+#if PJ_VERSION_NUM < (2 << 24 | 10 << 16)
+#error "Unsupported PJSIP version (requires version 2.10+)"
+#endif
+
 #include <istream>
 #include <algorithm>
 #include <regex>
@@ -74,24 +78,50 @@ using sip_utils::CONST_PJ_STR;
 static pjsip_endpoint* endpt_;
 static pjsip_module mod_ua_;
 
-static void sdp_media_update_cb(pjsip_inv_session* inv, pj_status_t status);
-static void sdp_request_offer_cb(pjsip_inv_session* inv, const pjmedia_sdp_session* offer);
-static void sdp_create_offer_cb(pjsip_inv_session* inv, pjmedia_sdp_session** p_offer);
 static void invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* e);
 static void outgoing_request_forked_cb(pjsip_inv_session* inv, pjsip_event* e);
 static void transaction_state_changed_cb(pjsip_inv_session* inv,
                                          pjsip_transaction* tsx,
                                          pjsip_event* e);
-static std::shared_ptr<SIPCall> getCallFromInvite(pjsip_inv_session* inv);
-static void processInviteResponseHelper(pjsip_inv_session* inv, pjsip_event* e);
+// Called when an SDP offer is found in answer. This will occur
+// when we send an empty invite (no SDP). In this case, we should
+// expect an offer in a the 200 OK message
+static void on_rx_offer2(pjsip_inv_session* inv, struct pjsip_inv_on_rx_offer_cb_param* param);
+// Called when a re-invite is received
+static pj_status_t reinvite_received_cb(pjsip_inv_session* inv,
+                                        const pjmedia_sdp_session* offer,
+                                        pjsip_rx_data* rdata);
+// Called to request an SDP offer if the peer sent an invite or
+// a re-invite with no SDP. In this, we must provide an offer in
+// the answer (200 OK) if we accept the call
+static void sdp_create_offer_cb(pjsip_inv_session* inv, pjmedia_sdp_session** p_offer);
+// Called to report media (SDP) negotiation result
+static void sdp_media_update_cb(pjsip_inv_session* inv, pj_status_t status);
 
-static void
+static std::shared_ptr<SIPCall> getCallFromInvite(pjsip_inv_session* inv);
+#ifdef DEBUG_SIP_REQUEST_MSG
+static void processInviteResponseHelper(pjsip_inv_session* inv, pjsip_event* e);
+#endif
+
+static pj_bool_t
 handleIncomingOptions(pjsip_rx_data* rdata)
 {
     pjsip_tx_data* tdata;
 
-    if (pjsip_endpt_create_response(endpt_, rdata, PJSIP_SC_OK, NULL, &tdata) != PJ_SUCCESS)
-        return;
+    auto dlg = pjsip_rdata_get_dlg(rdata);
+    if (dlg) {
+        JAMI_INFO("Processing in-dialog option request");
+        if (pjsip_dlg_create_response(dlg, rdata, PJSIP_SC_OK, NULL, &tdata) != PJ_SUCCESS) {
+            JAMI_ERR("Failed to create in-dialog response for option request");
+            return PJ_FALSE;
+        }
+    } else {
+        JAMI_INFO("Processing out-of-dialog option request");
+        if (pjsip_endpt_create_response(endpt_, rdata, PJSIP_SC_OK, NULL, &tdata) != PJ_SUCCESS) {
+            JAMI_ERR("Failed to create out-of-dialog response for option request");
+            return PJ_FALSE;
+        }
+    }
 
 #define ADD_HDR(hdr) \
     do { \
@@ -106,11 +136,27 @@ handleIncomingOptions(pjsip_rx_data* rdata)
     ADD_CAP(PJSIP_H_SUPPORTED);
     ADD_HDR(pjsip_evsub_get_allow_events_hdr(NULL));
 
+    if (dlg) {
+        if (pjsip_dlg_send_response(dlg, pjsip_rdata_get_tsx(rdata), tdata) != PJ_SUCCESS) {
+            JAMI_ERR("Failed to send in-dialog response for option request");
+            return PJ_FALSE;
+        }
+
+        JAMI_INFO("Sent in-dialog response for option request");
+        return PJ_TRUE;
+    }
+
     pjsip_response_addr res_addr;
     pjsip_get_response_addr(tdata->pool, rdata, &res_addr);
 
-    if (pjsip_endpt_send_response(endpt_, &res_addr, tdata, NULL, NULL) != PJ_SUCCESS)
+    if (pjsip_endpt_send_response(endpt_, &res_addr, tdata, NULL, NULL) != PJ_SUCCESS) {
         pjsip_tx_data_dec_ref(tdata);
+        JAMI_ERR("Failed to send out-of-dialog response for option request");
+        return PJ_FALSE;
+    }
+
+    JAMI_INFO("Sent out-of-dialog response for option request");
+    return PJ_TRUE;
 }
 
 // return PJ_FALSE so that eventually other modules will handle these requests
@@ -165,6 +211,14 @@ try_respond_stateless(pjsip_endpoint* endpt,
     return !PJ_SUCCESS;
 }
 
+template<typename T>
+bool
+is_uninitialized(std::weak_ptr<T> const& weak)
+{
+    using wt = std::weak_ptr<T>;
+    return !weak.owner_before(wt {}) && !wt {}.owner_before(weak);
+}
+
 static pj_bool_t
 transaction_request_cb(pjsip_rx_data* rdata)
 {
@@ -204,50 +258,70 @@ transaction_request_cb(pjsip_rx_data* rdata)
     std::string_view viaHostname(sip_via.host.ptr, sip_via.host.slen);
     const std::string_view remote_user(sip_from_uri->user.ptr, sip_from_uri->user.slen);
     const std::string_view remote_hostname(sip_from_uri->host.ptr, sip_from_uri->host.slen);
-    char tmp[PJSIP_MAX_URL_SIZE];
-    size_t length = pjsip_uri_print(PJSIP_URI_IN_FROMTO_HDR, sip_from_uri, tmp, PJSIP_MAX_URL_SIZE);
-    std::string peerNumber(tmp, length);
-    sip_utils::stripSipUriPrefix(peerNumber);
+    std::string peerNumber;
     if (not remote_user.empty() and not remote_hostname.empty())
         peerNumber = remote_user + "@" + remote_hostname;
+    else {
+        char tmp[PJSIP_MAX_URL_SIZE];
+        size_t length = pjsip_uri_print(PJSIP_URI_IN_FROMTO_HDR,
+                                        sip_from_uri,
+                                        tmp,
+                                        PJSIP_MAX_URL_SIZE);
+        peerNumber = sip_utils::stripSipUriPrefix(std::string_view(tmp, length));
+    }
 
-    auto account(
-        Manager::instance().sipVoIPLink().guessAccount(toUsername, viaHostname, remote_hostname));
-    if (!account) {
-        JAMI_ERR("NULL account");
+    auto transport = Manager::instance().sipVoIPLink().sipTransportBroker->addTransport(
+        rdata->tp_info.transport);
+
+    std::shared_ptr<SIPAccountBase> account;
+    // If transport account is default-constructed, guessing account is allowed
+    const auto& waccount = transport ? transport->getAccount() : std::weak_ptr<SIPAccountBase> {};
+    if (is_uninitialized(waccount)) {
+        account = Manager::instance().sipVoIPLink().guessAccount(toUsername,
+                                                                 viaHostname,
+                                                                 remote_hostname);
+        if (not account)
+            return PJ_FALSE;
+        if (not transport and not ::strcmp(account->getAccountType(), SIPAccount::ACCOUNT_TYPE)) {
+            if (not(transport = std::static_pointer_cast<SIPAccount>(account)->getTransport())) {
+                JAMI_ERR("No suitable transport to answer this call.");
+                return PJ_FALSE;
+            }
+            JAMI_WARN("Using transport from account.");
+        }
+    } else if (!(account = waccount.lock())) {
+        JAMI_ERR("Dropping SIP request: account is expired.");
         return PJ_FALSE;
     }
 
-    const auto& account_id = account->getAccountID();
     pjsip_msg_body* body = rdata->msg_info.msg->body;
 
     if (method->id == PJSIP_OTHER_METHOD) {
-        pj_str_t* str = &method->name;
-        std::string_view request(str->ptr, str->slen);
+        std::string_view request = sip_utils::as_view(method->name);
 
         if (request.find("NOTIFY") != std::string_view::npos) {
             if (body and body->data) {
-                int newCount {0};
-                int oldCount {0};
-                int urgentCount {0};
+                std::string_view body_view(static_cast<char*>(body->data), body->len);
+                auto pos = body_view.find("Voice-Message: ");
+                if (pos != std::string_view::npos) {
+                    int newCount {0};
+                    int oldCount {0};
+                    int urgentCount {0};
+                    std::string sp(body_view.substr(pos));
+                    int ret = sscanf(sp.c_str(),
+                                     "Voice-Message: %d/%d (%d/",
+                                     &newCount,
+                                     &oldCount,
+                                     &urgentCount);
 
-                std::string sp(static_cast<char*>(body->data), body->len);
-                auto pos = sp.find("Voice-Message: ");
-                sp = sp.substr(pos);
-
-                int ret = sscanf(sp.c_str(),
-                                 "Voice-Message: %d/%d (%d/",
-                                 &newCount,
-                                 &oldCount,
-                                 &urgentCount);
-
-                // According to rfc3842
-                // urgent messages are optional
-                if (ret >= 2)
-                    emitSignal<DRing::CallSignal::VoiceMailNotify>(account_id,
-                                                                   newCount,
-                                                                   oldCount,
-                                                                   urgentCount);
+                    // According to rfc3842
+                    // urgent messages are optional
+                    if (ret >= 2)
+                        emitSignal<DRing::CallSignal::VoiceMailNotify>(account->getAccountID(),
+                                                                       newCount,
+                                                                       oldCount,
+                                                                       urgentCount);
+                }
             }
         } else if (request.find("MESSAGE") != std::string_view::npos) {
             // Reply 200 immediately (RFC 3428, ch. 7)
@@ -280,7 +354,7 @@ transaction_request_cb(pjsip_rx_data* rdata)
                     } catch (...) {
                     }
                 }
-                account->onTextMessage(id, peerNumber, payloads);
+                account->onTextMessage(id, peerNumber, std::string(transport->deviceId()), payloads);
             }
             return PJ_FALSE;
         }
@@ -289,8 +363,7 @@ transaction_request_cb(pjsip_rx_data* rdata)
 
         return PJ_FALSE;
     } else if (method->id == PJSIP_OPTIONS_METHOD) {
-        handleIncomingOptions(rdata);
-        return PJ_FALSE;
+        return handleIncomingOptions(rdata);
     } else if (method->id != PJSIP_INVITE_METHOD && method->id != PJSIP_ACK_METHOD) {
         try_respond_stateless(endpt_, rdata, PJSIP_SC_METHOD_NOT_ALLOWED, NULL, NULL, NULL);
         return PJ_FALSE;
@@ -302,12 +375,15 @@ transaction_request_cb(pjsip_rx_data* rdata)
         sip_utils::logMessageHeaders(&rdata->msg_info.msg->hdr);
     }
 
-    pjmedia_sdp_session* r_sdp;
+    pjmedia_sdp_session* r_sdp {nullptr};
 
-    if (!body
-        || pjmedia_sdp_parse(rdata->tp_info.pool, (char*) body->data, body->len, &r_sdp)
-               != PJ_SUCCESS)
-        r_sdp = NULL;
+    if (body) {
+        if (pjmedia_sdp_parse(rdata->tp_info.pool, (char*) body->data, body->len, &r_sdp)
+            != PJ_SUCCESS) {
+            JAMI_WARN("Failed to parse the SDP in offer");
+            r_sdp = nullptr;
+        }
+    }
 
     if (not account->hasActiveCodec(MEDIA_AUDIO)) {
         try_respond_stateless(endpt_, rdata, PJSIP_SC_NOT_ACCEPTABLE_HERE, NULL, NULL, NULL);
@@ -323,45 +399,35 @@ transaction_request_cb(pjsip_rx_data* rdata)
         return PJ_FALSE;
     }
 
-    bool hasVideo = false;
-    if (r_sdp) {
-        auto pj_str_video = sip_utils::CONST_PJ_STR("video");
-        for (decltype(r_sdp->media_count) i = 0; i < r_sdp->media_count; i++) {
-            if (pj_strcmp(&r_sdp->media[i]->desc.media, &pj_str_video) == 0)
-                hasVideo = true;
+    // Build the initial media using the remote offer.
+    auto localMediaList = Sdp::getMediaAttributeListFromSdp(r_sdp);
+
+    // To enable video, it must be enabled in the remote and locally (i.e. in the account)
+    for (auto& media : localMediaList) {
+        if (media.type_ == MediaType::MEDIA_VIDEO) {
+            media.enabled_ &= account->isVideoEnabled();
         }
     }
 
-    auto transport = Manager::instance().sipVoIPLink().sipTransportBroker->addTransport(
-        rdata->tp_info.transport);
     auto call = account->newIncomingCall(std::string(remote_user),
-                                         {{"AUDIO_ONLY", (hasVideo ? "false" : "true")}},
+                                         MediaAttribute::mediaAttributesToMediaMaps(localMediaList),
                                          transport);
+
     if (!call) {
         return PJ_FALSE;
     }
 
+    call->setPeerUaVersion(sip_utils::getPeerUserAgent(rdata));
+
+    call->setTransport(transport);
+
     // JAMI_DBG("transaction_request_cb viaHostname %s toUsername %s addrToUse %s addrSdp %s
     // peerNumber: %s" , viaHostname.c_str(), toUsername.c_str(), addrToUse.toString().c_str(),
     // addrSdp.toString().c_str(), peerNumber.c_str());
 
-    // Append PJSIP transport to the broker's SipTransport list
-    if (!transport) {
-        if (not ::strcmp(account->getAccountType(), SIPAccount::ACCOUNT_TYPE)) {
-            JAMI_WARN("Using transport from account.");
-            transport = std::static_pointer_cast<SIPAccount>(account)->getTransport();
-        }
-        if (!transport) {
-            JAMI_ERR("No suitable transport to answer this call.");
-            return PJ_FALSE;
-        }
-    }
-    call->setTransport(transport);
-
     // FIXME : for now, use the same address family as the SIP transport
     auto family = pjsip_transport_type_get_af(
         pjsip_transport_get_type_from_flag(transport->get()->flag));
-    IpAddr addrToUse = ip_utils::getInterfaceAddr(account->getLocalInterface(), family);
 
     IpAddr addrSdp;
     if (account->getUPnPActive()) {
@@ -371,12 +437,12 @@ transaction_request_cb(pjsip_rx_data* rdata)
     } else {
         addrSdp = account->isStunEnabled() or (not account->getPublishedSameasLocal())
                       ? account->getPublishedIpAddress()
-                      : addrToUse;
+                      : ip_utils::getInterfaceAddr(account->getLocalInterface(), family);
     }
 
     /* fallback on local address */
     if (not addrSdp)
-        addrSdp = addrToUse;
+        addrSdp = ip_utils::getInterfaceAddr(account->getLocalInterface(), family);
 
     // Try to obtain display name from From: header first, fallback on Contact:
     auto peerDisplayName = sip_utils::parseDisplayName(rdata->msg_info.from);
@@ -393,16 +459,16 @@ transaction_request_cb(pjsip_rx_data* rdata)
     call->setState(Call::ConnectionState::PROGRESSING);
     call->getSDP().setPublishedIP(addrSdp);
 
-    if (account->isStunEnabled())
-        call->updateSDPFromSTUN();
+    // Set the temporary media list. Might change when we receive
+    // the accept from the client.
+    if (r_sdp != nullptr) {
+        call->getSDP().setReceivedOffer(r_sdp);
+        call->getSDP().processIncomingOffer(localMediaList);
+    }
 
-    call->getSDP().receiveOffer(r_sdp,
-                                account->getActiveAccountCodecInfoList(MEDIA_AUDIO),
-                                account->getActiveAccountCodecInfoList(
-                                    account->isVideoEnabled() and hasVideo ? MEDIA_VIDEO
-                                                                           : MEDIA_NONE),
-                                account->getSrtpKeyExchange());
-    call->setRemoteSdp(r_sdp);
+    if (r_sdp and call->isIceEnabled()) {
+        call->setupIceResponse();
+    }
 
     pjsip_dialog* dialog = nullptr;
     if (pjsip_dlg_create_uas_and_inc_lock(pjsip_ua_instance(), rdata, nullptr, &dialog)
@@ -442,12 +508,7 @@ transaction_request_cb(pjsip_rx_data* rdata)
     pjsip_dlg_dec_lock(dialog);
 
     inv->mod_data[mod_ua_.id] = call.get();
-    // NOTE: The invitation counter is managed by pjsip. If that counter goes down to zero
-    // the invite will be destroyed, and the unique_ptr will point freed datas.
-    // To avoid this, we increment the ref counter and let our unique_ptr manage
-    // when the invite will be freed
-    pjsip_inv_add_ref(inv);
-    call->inv.reset(inv);
+    call->setInviteSession(inv);
 
     // Check whether Replaces header is present in the request and process accordingly.
     pjsip_dialog* replaced_dlg;
@@ -472,39 +533,42 @@ transaction_request_cb(pjsip_rx_data* rdata)
     // Check if call has been transferred
     pjsip_tx_data* tdata = nullptr;
 
-    if (pjsip_inv_initial_answer(call->inv.get(), rdata, PJSIP_SC_TRYING, NULL, NULL, &tdata)
+    if (pjsip_inv_initial_answer(call->inviteSession_.get(),
+                                 rdata,
+                                 PJSIP_SC_TRYING,
+                                 NULL,
+                                 NULL,
+                                 &tdata)
         != PJ_SUCCESS) {
         JAMI_ERR("Could not create answer TRYING");
         return PJ_FALSE;
     }
 
     // Add user-agent header
-    sip_utils::addUserAgenttHeader(account->getUserAgentName(), tdata);
+    sip_utils::addUserAgentHeader(account->getUserAgentName(), tdata);
 
-    if (pjsip_inv_send_msg(call->inv.get(), tdata) != PJ_SUCCESS) {
+    if (pjsip_inv_send_msg(call->inviteSession_.get(), tdata) != PJ_SUCCESS) {
         JAMI_ERR("Could not send msg TRYING");
         return PJ_FALSE;
     }
 
     call->setState(Call::ConnectionState::TRYING);
 
-    if (pjsip_inv_answer(call->inv.get(), PJSIP_SC_RINGING, NULL, NULL, &tdata) != PJ_SUCCESS) {
+    if (pjsip_inv_answer(call->inviteSession_.get(), PJSIP_SC_RINGING, NULL, NULL, &tdata)
+        != PJ_SUCCESS) {
         JAMI_ERR("Could not create answer RINGING");
         return PJ_FALSE;
     }
 
-    // contactStr must stay in scope as long as tdata
-    const pj_str_t contactStr(account->getContactHeader(transport->get()));
-    sip_utils::addContactHeader(&contactStr, tdata);
-
-    if (pjsip_inv_send_msg(call->inv.get(), tdata) != PJ_SUCCESS) {
+    sip_utils::addContactHeader(account->getContactHeader(transport->get()), tdata);
+    if (pjsip_inv_send_msg(call->inviteSession_.get(), tdata) != PJ_SUCCESS) {
         JAMI_ERR("Could not send msg RINGING");
         return PJ_FALSE;
     }
 
     call->setState(Call::ConnectionState::RINGING);
 
-    Manager::instance().incomingCall(*call, account_id);
+    Manager::instance().incomingCall(*call, account->getAccountID());
 
     if (replaced_dlg) {
         // Get the INVITE session associated with the replaced dialog.
@@ -570,7 +634,6 @@ SIPVoIPLink::SIPVoIPLink()
             throw VoipLinkException(#ret " failed"); \
     } while (0)
 
-    sip_utils::register_thread();
     pj_caching_pool_init(&cp_, &pj_pool_factory_default_policy, 0);
     pool_.reset(pj_pool_create(&cp_.factory, PACKAGE, 64 * 1024, 4096, nullptr));
     if (!pool_)
@@ -628,7 +691,7 @@ SIPVoIPLink::SIPVoIPLink()
     TRY(pjsip_100rel_init_module(endpt_));
 
     // Initialize and register ring module
-    mod_ua_.name = pj_str((char*) PACKAGE);
+    mod_ua_.name = sip_utils::CONST_PJ_STR(PACKAGE);
     mod_ua_.id = -1;
     mod_ua_.priority = PJSIP_MOD_PRIORITY_APPLICATION;
     mod_ua_.on_rx_request = &transaction_request_cb;
@@ -642,22 +705,18 @@ SIPVoIPLink::SIPVoIPLink()
     TRY(pjsip_pres_init_module(endpt_, pjsip_evsub_instance()));
     TRY(pjsip_endpt_register_module(endpt_, &PresSubServer::mod_presence_server));
 
-    static const pjsip_inv_callback inv_cb
-        = { invite_session_state_changed_cb,
-            outgoing_request_forked_cb,
-            transaction_state_changed_cb,
-            sdp_request_offer_cb,
-#if PJ_VERSION_NUM >= (2 << 24 | 7 << 16)
-            nullptr /* on_rx_offer2 */,
-#endif
-#if PJ_VERSION_NUM > (2 << 24 | 1 << 16)
-            nullptr /* on_rx_reinvite */,
-#endif
-            sdp_create_offer_cb,
-            sdp_media_update_cb,
-            nullptr /* on_send_ack */,
-            nullptr /* on_redirected */,
-          };
+    static const pjsip_inv_callback inv_cb = {
+        invite_session_state_changed_cb,
+        outgoing_request_forked_cb,
+        transaction_state_changed_cb,
+        nullptr /* on_rx_offer */,
+        on_rx_offer2,
+        reinvite_received_cb,
+        sdp_create_offer_cb,
+        sdp_media_update_cb,
+        nullptr /* on_send_ack */,
+        nullptr /* on_redirected */,
+    };
     TRY(pjsip_inv_usage_init(endpt_, &inv_cb));
 
     static constexpr pj_str_t allowed[] = {
@@ -687,7 +746,6 @@ SIPVoIPLink::SIPVoIPLink()
 #undef TRY
 
     sipThread_ = std::thread([this] {
-        sip_utils::register_thread();
         while (running_)
             handleEvents();
     });
@@ -704,8 +762,9 @@ SIPVoIPLink::shutdown()
     // Remaining calls should not happen as possible upper callbacks
     // may be called and another instance of SIPVoIPLink can be re-created!
 
-    if (not Manager::instance().callFactory.empty<SIPCall>())
-        JAMI_ERR("%zu SIP calls remains!", Manager::instance().callFactory.callCount<SIPCall>());
+    if (not Manager::instance().callFactory.empty(Call::LinkType::SIP))
+        JAMI_ERR("%zu SIP calls remains!",
+                 Manager::instance().callFactory.callCount(Call::LinkType::SIP));
 
     sipTransportBroker->shutdown();
     pjsip_tpmgr_set_state_cb(pjsip_endpt_get_tpmgr(endpt_), nullptr);
@@ -726,34 +785,20 @@ SIPVoIPLink::guessAccount(std::string_view userName,
                           std::string_view fromUri) const
 {
     JAMI_DBG("username = %.*s, server = %.*s, from = %.*s",
-             (int)userName.size(), userName.data(),
-             (int)server.size(), server.data(),
-             (int)fromUri.size(), fromUri.data());
+             (int) userName.size(),
+             userName.data(),
+             (int) server.size(),
+             server.data(),
+             (int) fromUri.size(),
+             fromUri.data());
     // Try to find the account id from username and server name by full match
 
     std::shared_ptr<SIPAccountBase> result;
     std::shared_ptr<SIPAccountBase> IP2IPAccount;
     MatchRank best = MatchRank::NONE;
 
-    // DHT accounts
-    for (const auto& account : Manager::instance().getAllAccounts<JamiAccount>()) {
-        if (!account)
-            continue;
-        const MatchRank match(account->matches(userName, server));
-
-        // return right away if this is a full match
-        if (match == MatchRank::FULL) {
-            return account;
-        } else if (match > best) {
-            best = match;
-            result = account;
-        }
-    }
-
     // SIP accounts
     for (const auto& account : Manager::instance().getAllAccounts<SIPAccount>()) {
-        if (!account)
-            continue;
         const MatchRank match(account->matches(userName, server));
 
         // return right away if this is a full match
@@ -828,11 +873,16 @@ getCallFromInvite(pjsip_inv_session* inv)
 static void
 invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* ev)
 {
+    if (inv == nullptr or ev == nullptr) {
+        throw VoipLinkException("unexpected null pointer");
+    }
+
     auto call = getCallFromInvite(inv);
     if (not call)
         return;
 
-    if (ev->type != PJSIP_EVENT_TSX_STATE and ev->type != PJSIP_EVENT_TX_MSG) {
+    if (ev->type != PJSIP_EVENT_TSX_STATE and ev->type != PJSIP_EVENT_TX_MSG
+        and ev->type != PJSIP_EVENT_RX_MSG) {
         JAMI_WARN("[call:%s] INVITE@%p state changed to %d (%s): unexpected event type %d",
                   call->getCallId().c_str(),
                   inv,
@@ -842,9 +892,9 @@ invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* ev)
         return;
     }
 
-    decltype(pjsip_transaction::status_code) status_code;
+    decltype(pjsip_transaction::status_code) status_code = 0;
 
-    if (ev->type != PJSIP_EVENT_TX_MSG) {
+    if (ev->type == PJSIP_EVENT_TSX_STATE) {
         const auto tsx = ev->body.tsx_state.tsx;
         status_code = tsx ? tsx->status_code : PJSIP_SC_NOT_FOUND;
         const pj_str_t* description = pjsip_get_status_text(status_code);
@@ -859,8 +909,7 @@ invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* ev)
                  status_code,
                  (int) description->slen,
                  description->ptr);
-    } else {
-        status_code = 0;
+    } else if (ev->type == PJSIP_EVENT_TX_MSG) {
         JAMI_DBG("[call:%s] INVITE@%p state changed to %d (%s): cause=%d (TX_MSG)",
                  call->getCallId().c_str(),
                  inv,
@@ -869,6 +918,12 @@ invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* ev)
                  inv->cause);
     }
 
+    if (ev->type == PJSIP_EVENT_RX_MSG) {
+        call->setPeerUaVersion(sip_utils::getPeerUserAgent(ev->body.rx_msg.rdata));
+    } else if (ev->type == PJSIP_EVENT_TSX_STATE and ev->body.tsx_state.type == PJSIP_EVENT_RX_MSG) {
+        call->setPeerUaVersion(sip_utils::getPeerUserAgent(ev->body.tsx_state.src.rdata));
+    }
+
     switch (inv->state) {
     case PJSIP_INV_STATE_EARLY:
         if (status_code == PJSIP_SC_RINGING)
@@ -905,9 +960,6 @@ invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* ev)
             call->onFailure(inv->cause);
             break;
         }
-        // Reset the invite here as it must not be used on
-        // a non existing link and removeCall can take time to be called
-        call->inv.reset();
         break;
 
     default:
@@ -916,10 +968,48 @@ invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* ev)
 }
 
 static void
-sdp_request_offer_cb(pjsip_inv_session* inv, const pjmedia_sdp_session* offer)
+on_rx_offer2(pjsip_inv_session* inv, struct pjsip_inv_on_rx_offer_cb_param* param)
 {
-    if (auto call = getCallFromInvite(inv))
-        call->onReceiveOffer(offer);
+    if (not param or not param->offer) {
+        JAMI_ERR("Invalid offer");
+        return;
+    }
+
+    auto call = getCallFromInvite(inv);
+    if (not call)
+        return;
+
+    const auto msg = param->rdata->msg_info.msg;
+    if (msg->type != PJSIP_RESPONSE_MSG) {
+        JAMI_ERR("[call:%s] Ignore offer in '200 OK' answer", call->getCallId().c_str());
+        return;
+    }
+
+    if (auto call = getCallFromInvite(inv)) {
+        if (auto const& account = call->getAccount().lock()) {
+            call->onReceiveOfferIn200OK(param->offer);
+        }
+    }
+}
+
+static pj_status_t
+reinvite_received_cb(pjsip_inv_session* inv, const pjmedia_sdp_session* offer, pjsip_rx_data* rdata)
+{
+    if (!offer)
+        return !PJ_SUCCESS;
+    if (auto call = getCallFromInvite(inv)) {
+        if (auto const& account = call->getAccount().lock()) {
+            if (account->isMultiStreamEnabled()) {
+                return call->onReceiveReinvite(offer, rdata);
+            } else {
+                return call->onReceiveOffer(offer, rdata);
+            }
+        }
+    }
+
+    // Return success if there is no matching call. The re-invite
+    // should be ignored.
+    return PJ_SUCCESS;
 }
 
 static void
@@ -934,6 +1024,13 @@ sdp_create_offer_cb(pjsip_inv_session* inv, pjmedia_sdp_session** p_offer)
         JAMI_ERR("No account detected");
         return;
     }
+
+    if (account->isEmptyOffersEnabled()) {
+        // Skip if the client wants to send an empty offer.
+        JAMI_DBG("Client requested to send an empty offer (no SDP)");
+        return;
+    }
+
     auto family = pj_AF_INET();
     // FIXME : for now, use the same address family as the SIP transport
     if (auto dlg = inv->dlg) {
@@ -960,16 +1057,24 @@ sdp_create_offer_cb(pjsip_inv_session* inv, pjmedia_sdp_session** p_offer)
     if (not address)
         address = ifaceAddr;
 
-    auto& localSDP = call->getSDP();
-    localSDP.setPublishedIP(address);
-    const bool created = localSDP.createOffer(account->getActiveAccountCodecInfoList(MEDIA_AUDIO),
-                                              account->getActiveAccountCodecInfoList(
-                                                  account->isVideoEnabled() ? MEDIA_VIDEO
-                                                                            : MEDIA_NONE),
-                                              account->getSrtpKeyExchange());
+    auto& sdp = call->getSDP();
+    sdp.setPublishedIP(address);
 
-    if (created)
-        *p_offer = localSDP.getLocalSdpSession();
+    // This list should be provided by the client. Kept for backward compatibility.
+    auto const& mediaList = call->getMediaAttributeList();
+    if (mediaList.empty()) {
+        throw VoipLinkException("Unexpected empty media attribute list");
+    }
+
+    JAMI_DBG("Creating and SDP offer using the following media:");
+    for (auto const& media : mediaList) {
+        JAMI_DBG("[call %s] Media %s", call->getCallId().c_str(), media.toString(true).c_str());
+    }
+
+    const bool created = sdp.createOffer(mediaList);
+
+    if (created and p_offer != nullptr)
+        *p_offer = sdp.getLocalSdpSession();
 }
 
 static const pjmedia_sdp_session*
@@ -987,7 +1092,6 @@ get_active_remote_sdp(pjsip_inv_session* inv)
         return nullptr;
     }
 
-    Sdp::printSession(sdp_session, "Remote active SDP Session:\n");
     return sdp_session;
 }
 
@@ -1006,7 +1110,6 @@ get_active_local_sdp(pjsip_inv_session* inv)
         return nullptr;
     }
 
-    Sdp::printSession(sdp_session, "Local active SDP Session:\n");
     return sdp_session;
 }
 
@@ -1027,6 +1130,7 @@ sdp_media_update_cb(pjsip_inv_session* inv, pj_status_t status)
                                : 0;
 
         JAMI_WARN("[call:%s] SDP offer failed, reason %d", call->getCallId().c_str(), reason);
+
         call->hangup(reason);
         return;
     }
@@ -1038,9 +1142,15 @@ sdp_media_update_cb(pjsip_inv_session* inv, pj_status_t status)
     // Update our SDP manager
     auto& sdp = call->getSDP();
     sdp.setActiveLocalSdpSession(localSDP);
-    sdp.setActiveRemoteSdpSession(remoteSDP);
+    if (localSDP != nullptr) {
+        Sdp::printSession(localSDP, "Local active session:", sdp.getSdpDirection());
+    }
 
-    call->onMediaUpdate();
+    sdp.setActiveRemoteSdpSession(remoteSDP);
+    if (remoteSDP != nullptr) {
+        Sdp::printSession(remoteSDP, "Remote active session:", sdp.getSdpDirection());
+    }
+    call->onMediaNegotiationComplete();
 }
 
 static void
@@ -1058,22 +1168,21 @@ handleMediaControl(SIPCall& call, pjsip_msg_body* body)
 
     if (body->len and pj_stricmp(&body->content_type.type, &STR_APPLICATION) == 0
         and pj_stricmp(&body->content_type.subtype, &STR_MEDIA_CONTROL_XML) == 0) {
-        pj_str_t control_st;
+        auto body_msg = std::string_view((char*) body->data, (size_t) body->len);
 
         /* Apply and answer the INFO request */
-        pj_strset(&control_st, (char*) body->data, body->len);
-        static constexpr pj_str_t PICT_FAST_UPDATE = CONST_PJ_STR("picture_fast_update");
-        static constexpr pj_str_t DEVICE_ORIENTATION = CONST_PJ_STR("device_orientation");
-        static constexpr pj_str_t RECORDING_STATE = CONST_PJ_STR("recording_state");
+        static constexpr auto PICT_FAST_UPDATE = "picture_fast_update"sv;
+        static constexpr auto DEVICE_ORIENTATION = "device_orientation"sv;
+        static constexpr auto RECORDING_STATE = "recording_state"sv;
+        static constexpr auto MUTE_STATE = "mute_state"sv;
 
-        if (pj_strstr(&control_st, &PICT_FAST_UPDATE)) {
+        if (body_msg.find(PICT_FAST_UPDATE) != std::string_view::npos) {
             call.sendKeyframe();
             return true;
-        } else if (pj_strstr(&control_st, &DEVICE_ORIENTATION)) {
+        } else if (body_msg.find(DEVICE_ORIENTATION) != std::string_view::npos) {
             static const std::regex ORIENTATION_REGEX("device_orientation=([-+]?[0-9]+)");
 
-            std::string body_msg(control_st.ptr, control_st.slen);
-            std::smatch matched_pattern;
+            std::svmatch matched_pattern;
             std::regex_search(body_msg, matched_pattern, ORIENTATION_REGEX);
 
             if (matched_pattern.ready() && !matched_pattern.empty() && matched_pattern[1].matched) {
@@ -1085,28 +1194,43 @@ handleMediaControl(SIPCall& call, pjsip_msg_body* body)
                         rotation -= 360;
                     JAMI_WARN("Rotate video %d deg.", rotation);
 #ifdef ENABLE_VIDEO
-                    call.getVideoRtp().setRotation(rotation);
+                    auto const& videoRtp = call.getVideoRtp();
+                    if (videoRtp)
+                        videoRtp->setRotation(rotation);
 #endif
                 } catch (const std::exception& e) {
                     JAMI_WARN("Error parsing angle: %s", e.what());
                 }
                 return true;
             }
-        } else if (pj_strstr(&control_st, &RECORDING_STATE)) {
+        } else if (body_msg.find(RECORDING_STATE) != std::string_view::npos) {
             static const std::regex REC_REGEX("recording_state=([0-1])");
-            std::string body_msg(control_st.ptr, control_st.slen);
-            std::smatch matched_pattern;
+            std::svmatch matched_pattern;
             std::regex_search(body_msg, matched_pattern, REC_REGEX);
 
             if (matched_pattern.ready() && !matched_pattern.empty() && matched_pattern[1].matched) {
                 try {
                     bool state = std::stoi(matched_pattern[1]);
-                    call.setRemoteRecording(state);
+                    call.peerRecording(state);
                 } catch (const std::exception& e) {
                     JAMI_WARN("Error parsing state remote recording: %s", e.what());
                 }
                 return true;
             }
+        } else if (body_msg.find(MUTE_STATE) != std::string_view::npos) {
+            static const std::regex REC_REGEX("mute_state=([0-1])");
+            std::svmatch matched_pattern;
+            std::regex_search(body_msg, matched_pattern, REC_REGEX);
+
+            if (matched_pattern.ready() && !matched_pattern.empty() && matched_pattern[1].matched) {
+                try {
+                    bool state = std::stoi(matched_pattern[1]);
+                    call.peerMuted(state);
+                } catch (const std::exception& e) {
+                    JAMI_WARN("Error parsing state remote mute: %s", e.what());
+                }
+                return true;
+            }
         }
     }
 
@@ -1194,7 +1318,9 @@ transaction_state_changed_cb(pjsip_inv_session* inv, pjsip_transaction* tsx, pjs
     if (not call)
         return;
 
+#ifdef DEBUG_SIP_REQUEST_MSG
     processInviteResponseHelper(inv, event);
+#endif
 
     // We process here only incoming request message
     if (tsx->role != PJSIP_ROLE_UAS or tsx->state != PJSIP_TSX_STATE_TRYING
@@ -1215,9 +1341,12 @@ transaction_state_changed_cb(pjsip_inv_session* inv, pjsip_transaction* tsx, pjs
     }
 
     // Using method name to dispatch
-    const std::string methodName {msg->line.req.method.name.ptr,
-                                  (unsigned) msg->line.req.method.name.slen};
-    JAMI_DBG("[INVITE:%p] RX SIP method %d (%s)", inv, msg->line.req.method.id, methodName.c_str());
+    auto methodName = sip_utils::as_view(msg->line.req.method.name);
+    JAMI_DBG("[INVITE:%p] RX SIP method %d (%.*s)",
+             inv,
+             msg->line.req.method.id,
+             (int) methodName.size(),
+             methodName.data());
 
 #ifdef DEBUG_SIP_REQUEST_MSG
     char msgbuf[1000];
@@ -1231,6 +1360,8 @@ transaction_state_changed_cb(pjsip_inv_session* inv, pjsip_transaction* tsx, pjs
         onRequestInfo(inv, rdata, msg, *call);
     else if (methodName == "NOTIFY")
         onRequestNotify(inv, rdata, msg, *call);
+    else if (methodName == "OPTIONS")
+        handleIncomingOptions(rdata);
     else if (methodName == "MESSAGE") {
         if (msg->body)
             runOnMainThread([call, m = im::parseSipMessage(msg)]() mutable {
@@ -1239,6 +1370,7 @@ transaction_state_changed_cb(pjsip_inv_session* inv, pjsip_transaction* tsx, pjs
     }
 }
 
+#ifdef DEBUG_SIP_REQUEST_MSG
 static void
 processInviteResponseHelper(pjsip_inv_session* inv, pjsip_event* event)
 {
@@ -1263,13 +1395,15 @@ processInviteResponseHelper(pjsip_inv_session* inv, pjsip_event* event)
         return;
     }
 
-    JAMI_INFO("[INVITE:%p] SIP RX response: reason %s, status code %i",
+    JAMI_INFO("[INVITE:%p] SIP RX response: reason %.*s, status code %i",
               inv,
-              std::string(msg->line.status.reason.ptr, msg->line.status.reason.slen).c_str(),
+              (int) msg->line.status.reason.slen,
+              msg->line.status.reason.ptr,
               msg->line.status.code);
 
     sip_utils::logMessageHeaders(&msg->hdr);
 }
+#endif
 
 int
 SIPVoIPLink::getModId()
@@ -1278,10 +1412,12 @@ SIPVoIPLink::getModId()
 }
 
 void
-SIPVoIPLink::createSDPOffer(pjsip_inv_session* inv, pjmedia_sdp_session** p_offer)
+SIPVoIPLink::createSDPOffer(pjsip_inv_session* inv)
 {
-    assert(inv and p_offer);
-    sdp_create_offer_cb(inv, p_offer);
+    if (inv == nullptr) {
+        throw VoipLinkException("Invite session can not be null");
+    }
+    sdp_create_offer_cb(inv, nullptr);
 }
 
 // Thread-safe DNS resolver callback mapping
@@ -1410,8 +1546,7 @@ SIPVoIPLink::findLocalAddressFromTransport(pjsip_transport* transport,
     port = pjsip_transport_get_default_port_for_type(transportType);
 
     // Initialize the sip address with the hostname
-    const auto pjMachineName = pj_gethostname();
-    addr = std::string(pjMachineName->ptr, pjMachineName->slen);
+    addr = sip_utils::as_view(*pj_gethostname());
 
     // Update address and port with active transport
     RETURN_IF_NULL(transport,
@@ -1439,7 +1574,7 @@ SIPVoIPLink::findLocalAddressFromTransport(pjsip_transport* transport,
     }
 
     // Update local address based on the transport type
-    addr = std::string(param.ret_addr.ptr, param.ret_addr.slen);
+    addr = sip_utils::as_view(param.ret_addr);
 
     // Determine the local port based on transport information
     port = param.ret_port;
@@ -1479,14 +1614,7 @@ SIPVoIPLink::findLocalAddressFromSTUN(pjsip_transport* transport,
     pj_sockaddr_in mapped_addr;
     pj_sock_t sipSocket = pjsip_udp_transport_get_socket(transport);
     const pjstun_setting stunOpt
-        = { PJ_TRUE,
-#if PJ_VERSION_NUM > (2 << 24 | 7 << 16)
-            localIp.getFamily(),
-#endif
-            *stunServerName,
-            stunPort,
-            *stunServerName,
-            stunPort };
+        = {PJ_TRUE, localIp.getFamily(), *stunServerName, stunPort, *stunServerName, stunPort};
     const pj_status_t stunStatus = pjstun_get_mapped_addr2(&cp_.factory,
                                                            &stunOpt,
                                                            1,
