@@ -2,7 +2,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/qtwrapper/callmanager_wrap.h" line="328"/>
+        <location filename="../src/qtwrapper/callmanager_wrap.h" line="393"/>
         <source>Me</source>
         <translation>Io</translation>
     </message>
@@ -29,35 +29,35 @@
     <message>
         <location filename="../src/api/call.h" line="69"/>
         <source>Calling</source>
-        <translation>Chiamando</translation>
+        <translation>Stai chiamando</translation>
     </message>
     <message>
         <location filename="../src/api/call.h" line="71"/>
-        <location filename="../src/chatview.cpp" line="63"/>
+        <location filename="../src/chatview.cpp" line="72"/>
         <source>Connecting</source>
         <translation>Connessione in corso </translation>
     </message>
     <message>
         <location filename="../src/api/call.h" line="73"/>
         <source>Searching</source>
-        <translation>Ricerca in corso...</translation>
+        <translation>Ricerca in corso</translation>
     </message>
     <message>
         <location filename="../src/api/call.h" line="75"/>
         <source>Inactive</source>
-        <translation type="unfinished"/>
+        <translation>Inattivo</translation>
     </message>
     <message>
         <location filename="../src/api/call.h" line="77"/>
         <location filename="../src/api/call.h" line="83"/>
-        <location filename="../src/chatview.cpp" line="70"/>
+        <location filename="../src/chatview.cpp" line="79"/>
         <source>Finished</source>
-        <translation type="unfinished"/>
+        <translation>Completato</translation>
     </message>
     <message>
         <location filename="../src/api/call.h" line="79"/>
         <source>Timeout</source>
-        <translation type="unfinished"/>
+        <translation>Tempo scaduto</translation>
     </message>
     <message>
         <location filename="../src/api/call.h" line="81"/>
@@ -67,337 +67,345 @@
     <message>
         <location filename="../src/api/call.h" line="85"/>
         <source>Communication established</source>
-        <translation>Comunicazione stabilita</translation>
+        <translation>Connessione stabilita</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="130"/>
-        <location filename="../src/authority/storagehelper.cpp" line="898"/>
+        <location filename="../src/api/interaction.h" line="218"/>
+        <location filename="../src/authority/storagehelper.cpp" line="136"/>
+        <location filename="../src/authority/storagehelper.cpp" line="954"/>
         <source>Invitation received</source>
         <translation>Invito ricevuto</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="127"/>
-        <location filename="../src/authority/storagehelper.cpp" line="896"/>
+        <location filename="../src/api/interaction.h" line="222"/>
+        <source>Contact left conversation</source>
+        <translation>Il contatto ha chiuso la conversazione</translation>
+    </message>
+    <message>
+        <location filename="../src/api/interaction.h" line="216"/>
+        <location filename="../src/authority/storagehelper.cpp" line="133"/>
+        <location filename="../src/authority/storagehelper.cpp" line="952"/>
         <source>Contact added</source>
         <translation>Contatto aggiunto</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="104"/>
         <location filename="../src/authority/storagehelper.cpp" line="110"/>
-        <location filename="../src/authority/storagehelper.cpp" line="894"/>
+        <location filename="../src/authority/storagehelper.cpp" line="116"/>
+        <location filename="../src/authority/storagehelper.cpp" line="950"/>
         <source>Outgoing call</source>
         <translation>Chiamata in uscita</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="106"/>
-        <location filename="../src/authority/storagehelper.cpp" line="116"/>
+        <location filename="../src/authority/storagehelper.cpp" line="112"/>
+        <location filename="../src/authority/storagehelper.cpp" line="122"/>
         <source>Incoming call</source>
         <translation>Chiamata in arrivo</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="112"/>
-        <location filename="../src/authority/storagehelper.cpp" line="892"/>
+        <location filename="../src/authority/storagehelper.cpp" line="118"/>
+        <location filename="../src/authority/storagehelper.cpp" line="948"/>
         <source>Missed outgoing call</source>
         <translation>Chiamata in uscita persa</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="118"/>
+        <location filename="../src/authority/storagehelper.cpp" line="124"/>
         <source>Missed incoming call</source>
-        <translation>Chiamata in entrata persa</translation>
+        <translation>Chiamata in arrivo persa</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="132"/>
-        <location filename="../src/authority/storagehelper.cpp" line="900"/>
+        <location filename="../src/api/interaction.h" line="220"/>
+        <location filename="../src/authority/storagehelper.cpp" line="138"/>
+        <location filename="../src/authority/storagehelper.cpp" line="956"/>
         <source>Invitation accepted</source>
-        <translation type="unfinished"/>
+        <translation>Invito accettato</translation>
     </message>
     <message>
-        <location filename="../src/avmodel.cpp" line="335"/>
-        <location filename="../src/avmodel.cpp" line="354"/>
+        <location filename="../src/avmodel.cpp" line="339"/>
+        <location filename="../src/avmodel.cpp" line="358"/>
         <source>default</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="53"/>
-        <source>Null</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="54"/>
-        <source>Trying</source>
-        <translation type="unfinished"/>
+        <translation>predefinito</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="55"/>
-        <source>Ringing</source>
-        <translation>Suonando</translation>
+        <source>Null</source>
+        <translation>Null</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="56"/>
-        <source>Being Forwarded</source>
-        <translation type="unfinished"/>
+        <source>Trying</source>
+        <translation>Tentativo</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="57"/>
-        <source>Queued</source>
-        <translation type="unfinished"/>
+        <source>Ringing</source>
+        <translation>Sta squillando</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="58"/>
-        <source>Progress</source>
-        <translation type="unfinished"/>
+        <source>Being Forwarded</source>
+        <translation>In inoltro</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="59"/>
+        <source>Queued</source>
+        <translation>In coda</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="60"/>
+        <source>Progress</source>
+        <translation>In corso</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="61"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="64"/>
-        <location filename="../src/newcallmodel.cpp" line="60"/>
-        <source>Accepted</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="61"/>
-        <source>Multiple Choices</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
+        <location filename="../src/chatview.cpp" line="73"/>
         <location filename="../src/newcallmodel.cpp" line="62"/>
-        <source>Moved Permanently</source>
-        <translation type="unfinished"/>
+        <source>Accepted</source>
+        <translation>Accettato</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="63"/>
-        <source>Moved Temporarily</source>
-        <translation type="unfinished"/>
+        <source>Multiple Choices</source>
+        <translation>Scelta multipla</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="64"/>
-        <source>Use Proxy</source>
-        <translation type="unfinished"/>
+        <source>Moved Permanently</source>
+        <translation>Spostato definitivamente</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="65"/>
-        <source>Alternative Service</source>
-        <translation type="unfinished"/>
+        <source>Moved Temporarily</source>
+        <translation>Spostato temporaneamente</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="66"/>
-        <source>Bad Request</source>
-        <translation type="unfinished"/>
+        <source>Use Proxy</source>
+        <translation>Usa proxy</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="67"/>
-        <source>Unauthorized</source>
-        <translation type="unfinished"/>
+        <source>Alternative Service</source>
+        <translation>Servizio alternativo</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="68"/>
-        <source>Payment Required</source>
-        <translation type="unfinished"/>
+        <source>Bad Request</source>
+        <translation>Richiesta errata</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="69"/>
-        <source>Forbidden</source>
-        <translation type="unfinished"/>
+        <source>Unauthorized</source>
+        <translation>Non autorizzato</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="70"/>
-        <source>Not Found</source>
-        <translation type="unfinished"/>
+        <source>Payment Required</source>
+        <translation>Pagamento richiesto</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="71"/>
-        <source>Method Not Allowed</source>
-        <translation type="unfinished"/>
+        <source>Forbidden</source>
+        <translation>Vietato</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="72"/>
-        <location filename="../src/newcallmodel.cpp" line="92"/>
-        <source>Not Acceptable</source>
-        <translation type="unfinished"/>
+        <source>Not Found</source>
+        <translation>Non trovato</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="73"/>
-        <source>Proxy Authentication Required</source>
-        <translation type="unfinished"/>
+        <source>Method Not Allowed</source>
+        <translation>Metodo non permesso</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="74"/>
-        <source>Request Timeout</source>
-        <translation>Richiedi Timeout</translation>
+        <location filename="../src/newcallmodel.cpp" line="94"/>
+        <source>Not Acceptable</source>
+        <translation>Non accettabile</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="75"/>
-        <source>Gone</source>
-        <translation type="unfinished"/>
+        <source>Proxy Authentication Required</source>
+        <translation>Richiesta autenticazione proxy</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="76"/>
-        <source>Request Entity Too Large</source>
-        <translation type="unfinished"/>
+        <source>Request Timeout</source>
+        <translation>Tempo scaduto</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="77"/>
-        <source>Request URI Too Long</source>
-        <translation type="unfinished"/>
+        <source>Gone</source>
+        <translation>Non disponibile</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="78"/>
-        <source>Unsupported Media Type</source>
-        <translation type="unfinished"/>
+        <source>Request Entity Too Large</source>
+        <translation>Entità richiesta troppo grande</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="79"/>
-        <source>Unsupported URI Scheme</source>
-        <translation type="unfinished"/>
+        <source>Request URI Too Long</source>
+        <translation>l&apos;URI richiesto è troppo lungo</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="80"/>
-        <source>Bad Extension</source>
-        <translation type="unfinished"/>
+        <source>Unsupported Media Type</source>
+        <translation>Tipo di Media non accettato</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="81"/>
-        <source>Extension Required</source>
-        <translation type="unfinished"/>
+        <source>Unsupported URI Scheme</source>
+        <translation>Schema URI non accettato</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="82"/>
-        <source>Session Timer Too Small</source>
-        <translation type="unfinished"/>
+        <source>Bad Extension</source>
+        <translation>Estensione errata</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="83"/>
-        <source>Interval Too Brief</source>
-        <translation type="unfinished"/>
+        <source>Extension Required</source>
+        <translation>Estensione richiesta</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="84"/>
-        <source>Temporarily Unavailable</source>
-        <translation type="unfinished"/>
+        <source>Session Timer Too Small</source>
+        <translation>Tempo di sessione troppo breve</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="85"/>
-        <source>Call TSX Does Not Exist</source>
-        <translation type="unfinished"/>
+        <source>Interval Too Brief</source>
+        <translation>Intervallo troppo breve</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="86"/>
-        <source>Loop Detected</source>
-        <translation type="unfinished"/>
+        <source>Temporarily Unavailable</source>
+        <translation>Temporaneamente non disponibile</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="87"/>
-        <source>Too Many Hops</source>
-        <translation type="unfinished"/>
+        <source>Call TSX Does Not Exist</source>
+        <translation>Chiamata TSX non esiste</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="88"/>
-        <source>Address Incomplete</source>
-        <translation type="unfinished"/>
+        <source>Loop Detected</source>
+        <translation>Rilevato loop</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="89"/>
-        <source>Ambiguous</source>
-        <translation type="unfinished"/>
+        <source>Too Many Hops</source>
+        <translation>Troppi Hop</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="90"/>
+        <source>Address Incomplete</source>
+        <translation>Indirizzo incompleto</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="91"/>
+        <source>Ambiguous</source>
+        <translation>Ambiguo</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="92"/>
         <source>Busy</source>
         <translation>Occupato</translation>
     </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="91"/>
-        <source>Request Terminated</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="93"/>
-        <source>Bad Event</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="94"/>
-        <source>Request Updated</source>
-        <translation type="unfinished"/>
+        <source>Request Terminated</source>
+        <translation>Richiesta terminata</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="95"/>
-        <source>Request Pending</source>
-        <translation type="unfinished"/>
+        <source>Bad Event</source>
+        <translation>Evento negativo</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="96"/>
-        <source>Undecipherable</source>
-        <translation type="unfinished"/>
+        <source>Request Updated</source>
+        <translation>Richiesta aggiornata</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="97"/>
-        <source>Internal Server Error</source>
-        <translation type="unfinished"/>
+        <source>Request Pending</source>
+        <translation>Richiesta in corso</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="98"/>
-        <source>Not Implemented</source>
-        <translation type="unfinished"/>
+        <source>Undecipherable</source>
+        <translation>Indecifrabile</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="99"/>
-        <source>Bad Gateway</source>
-        <translation type="unfinished"/>
+        <source>Internal Server Error</source>
+        <translation>Errore interno del server</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="100"/>
-        <source>Service Unavailable</source>
-        <translation type="unfinished"/>
+        <source>Not Implemented</source>
+        <translation>Non implementato</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="101"/>
-        <source>Server Timeout</source>
-        <translation type="unfinished"/>
+        <source>Bad Gateway</source>
+        <translation>Gateway incorretto</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="102"/>
-        <source>Version Not Supported</source>
-        <translation type="unfinished"/>
+        <source>Service Unavailable</source>
+        <translation>Servizio non disponibile</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="103"/>
-        <source>Message Too Large</source>
-        <translation type="unfinished"/>
+        <source>Server Timeout</source>
+        <translation>Tempo scaduto per il server</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="104"/>
-        <source>Precondition Failure</source>
-        <translation type="unfinished"/>
+        <source>Version Not Supported</source>
+        <translation>Versione non supportata</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="105"/>
-        <source>Busy Everywhere</source>
-        <translation type="unfinished"/>
+        <source>Message Too Large</source>
+        <translation>Messaggio troppo grande</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="106"/>
-        <source>Call Refused</source>
-        <translation type="unfinished"/>
+        <source>Precondition Failure</source>
+        <translation>Fallimento della precondizione</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="107"/>
-        <source>Does Not Exist Anywhere</source>
-        <translation type="unfinished"/>
+        <source>Busy Everywhere</source>
+        <translation>Occupato ovunque</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="108"/>
+        <source>Call Refused</source>
+        <translation>Chiamata rifiutata</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="109"/>
+        <source>Does Not Exist Anywhere</source>
+        <translation>Non esiste da nessuna parte</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="110"/>
         <source>Not Acceptable Anywhere</source>
-        <translation type="unfinished"/>
+        <translation>Non accettabile ovunque</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="30"/>
         <source>Hide chat view</source>
-        <translation>Nascondere la vista del chat</translation>
+        <translation>Nascondi vista chat</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="31"/>
@@ -407,12 +415,12 @@
     <message>
         <location filename="../src/chatview.cpp" line="32"/>
         <source>Show available plugins</source>
-        <translation type="unfinished"/>
+        <translation>Mostra i plugin disponibili</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="33"/>
         <source>Place audio call</source>
-        <translation>Effettua chiamata audio</translation>
+        <translation>Effettua chiamata vocale</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="34"/>
@@ -432,12 +440,12 @@
     <message>
         <location filename="../src/chatview.cpp" line="37"/>
         <source>Options</source>
-        <translation type="unfinished"/>
+        <translation>Opzioni</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="38"/>
         <source>Jump to latest</source>
-        <translation type="unfinished"/>
+        <translation>Vai all&apos;ultimo</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="39"/>
@@ -447,42 +455,77 @@
     <message>
         <location filename="../src/chatview.cpp" line="40"/>
         <source>Add emoji</source>
-        <translation type="unfinished"/>
+        <translation>Aggiungi emoji</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="41"/>
         <source>Leave video message</source>
-        <translation type="unfinished"/>
+        <translation>Registra videomessaggio</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="42"/>
         <source>Leave audio message</source>
-        <translation type="unfinished"/>
+        <translation>Registra messaggio vocale</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="44"/>
+        <source>Copy to downloads</source>
+        <translation>Copia per scaricare</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="45"/>
         <source>Write to {0}</source>
         <translation>Scrivi a {0}</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="62"/>
-        <source>Unable to make contact</source>
-        <translation type="unfinished"/>
+        <location filename="../src/chatview.cpp" line="50"/>
+        <source>has sent you a conversation request.</source>
+        <translation>ti ha inviato una richiesta di conversazione.</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="52"/>
+        <source>Hello, do you want to join the conversation?</source>
+        <translation>Ciao, vuoi partecipare alla conversazione?</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="54"/>
+        <source>You have accepted the conversation request.</source>
+        <translation>Hai accettato la richiesta di conversazione.</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="56"/>
+        <source>We are waiting for another device to synchronize the conversation.</source>
+        <translation>In attesa che altri dispositivi sincronizzino la conversazione.</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="67"/>
-        <source>Waiting for contact</source>
-        <translation type="unfinished"/>
+        <source>Accept</source>
+        <translation>Accetta</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="68"/>
-        <source>Incoming transfer</source>
-        <translation type="unfinished"/>
+        <source>Refuse</source>
+        <translation>Rifiuta</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="69"/>
+        <location filename="../src/chatview.cpp" line="71"/>
+        <source>Unable to make contact</source>
+        <translation>Impossibile prendere contatto</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="76"/>
+        <source>Waiting for contact</source>
+        <translation>In attesa di contatto</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="77"/>
+        <source>Incoming transfer</source>
+        <translation>Trasferimento in entrata</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="78"/>
         <source>Timed out waiting for contact</source>
-        <translation type="unfinished"/>
+        <translation>Tempo scaduto in attesa di contatto</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="43"/>
@@ -490,97 +533,87 @@
         <translation>Blocca</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="46"/>
+        <location filename="../src/chatview.cpp" line="47"/>
         <source>Note: an interaction will create a new contact.</source>
         <translation>Nota: un&apos;interazione creerà un nuovo contatto.</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="47"/>
+        <location filename="../src/chatview.cpp" line="48"/>
         <source>is not in your contacts</source>
-        <translation type="unfinished"/>
+        <translation>non è nei tuoi contatti</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="49"/>
+        <location filename="../src/chatview.cpp" line="58"/>
         <source>Note: you can automatically accept this invitation by sending a message.</source>
         <translation>Nota: puoi accettare automaticamente questo invito inviando un messaggio.</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="50"/>
+        <location filename="../src/chatview.cpp" line="59"/>
         <source>{0} days ago</source>
-        <translation type="unfinished"/>
+        <translation>{0} giorni fa</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="51"/>
+        <location filename="../src/chatview.cpp" line="60"/>
         <source>{0} hours ago</source>
-        <translation type="unfinished"/>
+        <translation>{0} ore fa</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="53"/>
+        <location filename="../src/chatview.cpp" line="62"/>
         <source>{0} minutes ago</source>
-        <translation type="unfinished"/>
+        <translation>{0} minuti fa</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="65"/>
+        <location filename="../src/chatview.cpp" line="74"/>
         <source>Canceled</source>
-        <translation type="unfinished"/>
+        <translation>Annullato</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="66"/>
+        <location filename="../src/chatview.cpp" line="75"/>
         <source>Ongoing</source>
-        <translation type="unfinished"/>
+        <translation>In corso</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="50"/>
+        <location filename="../src/chatview.cpp" line="59"/>
         <source>%d days ago</source>
         <translation>%d giorni fa</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="51"/>
+        <location filename="../src/chatview.cpp" line="60"/>
         <source>%d hours ago</source>
         <translation>%d ore fa</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="53"/>
+        <location filename="../src/chatview.cpp" line="62"/>
         <source>%d minutes ago</source>
         <translation>%d minuti fa</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="54"/>
+        <location filename="../src/chatview.cpp" line="63"/>
         <source>one day ago</source>
         <translation>un giorno fa</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="55"/>
+        <location filename="../src/chatview.cpp" line="64"/>
         <source>one hour ago</source>
         <translation>un&apos;ora fa</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="56"/>
+        <location filename="../src/chatview.cpp" line="65"/>
         <source>just now</source>
         <translation>ora</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="57"/>
+        <location filename="../src/chatview.cpp" line="66"/>
         <source>Failure</source>
         <translation>Fallimento</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="58"/>
-        <source>Confirm</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/chatview.cpp" line="59"/>
-        <source>Deny</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/chatview.cpp" line="60"/>
+        <location filename="../src/chatview.cpp" line="69"/>
         <source>Delete</source>
         <translation>Elimina</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="61"/>
+        <location filename="../src/chatview.cpp" line="70"/>
         <source>Retry</source>
         <translation>Riprova</translation>
     </message>
@@ -588,32 +621,32 @@
 <context>
     <name>lrc::ContactModelPimpl</name>
     <message>
-        <location filename="../src/contactmodel.cpp" line="459"/>
+        <location filename="../src/contactmodel.cpp" line="474"/>
         <source>Searching…</source>
-        <translation type="unfinished"/>
+        <translation>Ricerca in corso...</translation>
     </message>
     <message>
-        <location filename="../src/contactmodel.cpp" line="955"/>
+        <location filename="../src/contactmodel.cpp" line="999"/>
         <source>Invalid ID</source>
-        <translation type="unfinished"/>
+        <translation>ID non valido</translation>
     </message>
     <message>
-        <location filename="../src/contactmodel.cpp" line="958"/>
-        <source>Registered name not found</source>
-        <translation type="unfinished"/>
+        <location filename="../src/contactmodel.cpp" line="1002"/>
+        <source>Username not found</source>
+        <translation>Nome utente non trovato</translation>
     </message>
     <message>
-        <location filename="../src/contactmodel.cpp" line="961"/>
+        <location filename="../src/contactmodel.cpp" line="1005"/>
         <source>Couldn&apos;t lookup…</source>
-        <translation type="unfinished"/>
+        <translation>Impossibile cercare…</translation>
     </message>
 </context>
 <context>
     <name>lrc::api::ContactModel</name>
     <message>
-        <location filename="../src/contactmodel.cpp" line="420"/>
+        <location filename="../src/contactmodel.cpp" line="435"/>
         <source>Bad URI scheme</source>
-        <translation type="unfinished"/>
+        <translation>Schema URI errato</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
