@@ -2,7 +2,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/qtwrapper/callmanager_wrap.h" line="328"/>
+        <location filename="../src/qtwrapper/callmanager_wrap.h" line="393"/>
         <source>Me</source>
         <translation>Ja</translation>
     </message>
@@ -33,6 +33,7 @@
     </message>
     <message>
         <location filename="../src/api/call.h" line="71"/>
+        <location filename="../src/chatview.cpp" line="72"/>
         <source>Connecting</source>
         <translation>Łączenie</translation>
     </message>
@@ -49,6 +50,7 @@
     <message>
         <location filename="../src/api/call.h" line="77"/>
         <location filename="../src/api/call.h" line="83"/>
+        <location filename="../src/chatview.cpp" line="79"/>
         <source>Finished</source>
         <translation>Zakończono</translation>
     </message>
@@ -68,326 +70,335 @@
         <translation>Połączenie się powiodło </translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="130"/>
-        <location filename="../src/authority/storagehelper.cpp" line="898"/>
+        <location filename="../src/api/interaction.h" line="218"/>
+        <location filename="../src/authority/storagehelper.cpp" line="136"/>
+        <location filename="../src/authority/storagehelper.cpp" line="954"/>
         <source>Invitation received</source>
         <translation>Otrzymano zaproszenie</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="127"/>
-        <location filename="../src/authority/storagehelper.cpp" line="896"/>
+        <location filename="../src/api/interaction.h" line="222"/>
+        <source>Contact left conversation</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/api/interaction.h" line="216"/>
+        <location filename="../src/authority/storagehelper.cpp" line="133"/>
+        <location filename="../src/authority/storagehelper.cpp" line="952"/>
         <source>Contact added</source>
         <translation>Kontakt dodany</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="104"/>
         <location filename="../src/authority/storagehelper.cpp" line="110"/>
-        <location filename="../src/authority/storagehelper.cpp" line="894"/>
+        <location filename="../src/authority/storagehelper.cpp" line="116"/>
+        <location filename="../src/authority/storagehelper.cpp" line="950"/>
         <source>Outgoing call</source>
         <translation>Połączenie wychodzące</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="106"/>
-        <location filename="../src/authority/storagehelper.cpp" line="116"/>
+        <location filename="../src/authority/storagehelper.cpp" line="112"/>
+        <location filename="../src/authority/storagehelper.cpp" line="122"/>
         <source>Incoming call</source>
         <translation>Połączenie przychodzące</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="112"/>
-        <location filename="../src/authority/storagehelper.cpp" line="892"/>
+        <location filename="../src/authority/storagehelper.cpp" line="118"/>
+        <location filename="../src/authority/storagehelper.cpp" line="948"/>
         <source>Missed outgoing call</source>
         <translation>Nieodebrane połączenie wychodzące</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="118"/>
+        <location filename="../src/authority/storagehelper.cpp" line="124"/>
         <source>Missed incoming call</source>
         <translation>Nieodebrane połączenie przychodzące</translation>
     </message>
     <message>
-        <location filename="../src/authority/storagehelper.cpp" line="132"/>
-        <location filename="../src/authority/storagehelper.cpp" line="900"/>
+        <location filename="../src/api/interaction.h" line="220"/>
+        <location filename="../src/authority/storagehelper.cpp" line="138"/>
+        <location filename="../src/authority/storagehelper.cpp" line="956"/>
         <source>Invitation accepted</source>
         <translation>Zaakceptowano zaproszenie</translation>
     </message>
     <message>
-        <location filename="../src/avmodel.cpp" line="330"/>
-        <location filename="../src/avmodel.cpp" line="349"/>
+        <location filename="../src/avmodel.cpp" line="339"/>
+        <location filename="../src/avmodel.cpp" line="358"/>
         <source>default</source>
         <translation>domyślne</translation>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="53"/>
+        <location filename="../src/newcallmodel.cpp" line="55"/>
         <source>Null</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="54"/>
+        <location filename="../src/newcallmodel.cpp" line="56"/>
         <source>Trying</source>
-        <translation type="unfinished"/>
+        <translation>Próbowanie</translation>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="55"/>
+        <location filename="../src/newcallmodel.cpp" line="57"/>
         <source>Ringing</source>
         <translation>Dzwonienie</translation>
     </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="56"/>
-        <source>Being Forwarded</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="57"/>
-        <source>Queued</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="58"/>
-        <source>Progress</source>
-        <translation type="unfinished"/>
+        <source>Being Forwarded</source>
+        <translation>Jest Przekazywane</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="59"/>
+        <source>Queued</source>
+        <translation>W kolejce</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="60"/>
+        <source>Progress</source>
+        <translation>Progres</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="61"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="60"/>
-        <source>Accepted</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="61"/>
-        <source>Multiple Choices</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
+        <location filename="../src/chatview.cpp" line="73"/>
         <location filename="../src/newcallmodel.cpp" line="62"/>
-        <source>Moved Permanently</source>
-        <translation type="unfinished"/>
+        <source>Accepted</source>
+        <translation>Zaakceptowane</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="63"/>
-        <source>Moved Temporarily</source>
-        <translation type="unfinished"/>
+        <source>Multiple Choices</source>
+        <translation>Wiele Wyborów</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="64"/>
-        <source>Use Proxy</source>
-        <translation type="unfinished"/>
+        <source>Moved Permanently</source>
+        <translation>Przeniesione Na Stałe</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="65"/>
-        <source>Alternative Service</source>
-        <translation type="unfinished"/>
+        <source>Moved Temporarily</source>
+        <translation>Przeniesione Tymczasowo</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="66"/>
-        <source>Bad Request</source>
-        <translation type="unfinished"/>
+        <source>Use Proxy</source>
+        <translation>Używaj Proxy</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="67"/>
-        <source>Unauthorized</source>
-        <translation type="unfinished"/>
+        <source>Alternative Service</source>
+        <translation>Alternatywna Usługa</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="68"/>
-        <source>Payment Required</source>
-        <translation type="unfinished"/>
+        <source>Bad Request</source>
+        <translation>Nieprawidłowe zapytanie</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="69"/>
-        <source>Forbidden</source>
-        <translation type="unfinished"/>
+        <source>Unauthorized</source>
+        <translation>Nieautoryzowany</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="70"/>
-        <source>Not Found</source>
-        <translation type="unfinished"/>
+        <source>Payment Required</source>
+        <translation>Wymagana Płatność</translation>
     </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="71"/>
+        <source>Forbidden</source>
+        <translation>Zabroniony</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="72"/>
+        <source>Not Found</source>
+        <translation>Nie Znaleziono</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="73"/>
         <source>Method Not Allowed</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="72"/>
-        <location filename="../src/newcallmodel.cpp" line="92"/>
-        <source>Not Acceptable</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../src/newcallmodel.cpp" line="73"/>
-        <source>Proxy Authentication Required</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <location filename="../src/newcallmodel.cpp" line="74"/>
+        <location filename="../src/newcallmodel.cpp" line="94"/>
+        <source>Not Acceptable</source>
+        <translation>Nieakceptowalne</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="75"/>
+        <source>Proxy Authentication Required</source>
+        <translation>Wymagane Uwierzytelnienie Proxy</translation>
+    </message>
+    <message>
+        <location filename="../src/newcallmodel.cpp" line="76"/>
         <source>Request Timeout</source>
         <translation>Prośba przekroczyła czas oczekiwania</translation>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="75"/>
+        <location filename="../src/newcallmodel.cpp" line="77"/>
         <source>Gone</source>
-        <translation type="unfinished"/>
+        <translation>Zniknął</translation>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="76"/>
+        <location filename="../src/newcallmodel.cpp" line="78"/>
         <source>Request Entity Too Large</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="77"/>
+        <location filename="../src/newcallmodel.cpp" line="79"/>
         <source>Request URI Too Long</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="78"/>
+        <location filename="../src/newcallmodel.cpp" line="80"/>
         <source>Unsupported Media Type</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="79"/>
+        <location filename="../src/newcallmodel.cpp" line="81"/>
         <source>Unsupported URI Scheme</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="80"/>
+        <location filename="../src/newcallmodel.cpp" line="82"/>
         <source>Bad Extension</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="81"/>
+        <location filename="../src/newcallmodel.cpp" line="83"/>
         <source>Extension Required</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="82"/>
+        <location filename="../src/newcallmodel.cpp" line="84"/>
         <source>Session Timer Too Small</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="83"/>
+        <location filename="../src/newcallmodel.cpp" line="85"/>
         <source>Interval Too Brief</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="84"/>
+        <location filename="../src/newcallmodel.cpp" line="86"/>
         <source>Temporarily Unavailable</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="85"/>
+        <location filename="../src/newcallmodel.cpp" line="87"/>
         <source>Call TSX Does Not Exist</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="86"/>
+        <location filename="../src/newcallmodel.cpp" line="88"/>
         <source>Loop Detected</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="87"/>
+        <location filename="../src/newcallmodel.cpp" line="89"/>
         <source>Too Many Hops</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="88"/>
+        <location filename="../src/newcallmodel.cpp" line="90"/>
         <source>Address Incomplete</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="89"/>
+        <location filename="../src/newcallmodel.cpp" line="91"/>
         <source>Ambiguous</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="90"/>
+        <location filename="../src/newcallmodel.cpp" line="92"/>
         <source>Busy</source>
         <translation>Zajęty</translation>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="91"/>
+        <location filename="../src/newcallmodel.cpp" line="93"/>
         <source>Request Terminated</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="93"/>
+        <location filename="../src/newcallmodel.cpp" line="95"/>
         <source>Bad Event</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="94"/>
+        <location filename="../src/newcallmodel.cpp" line="96"/>
         <source>Request Updated</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="95"/>
+        <location filename="../src/newcallmodel.cpp" line="97"/>
         <source>Request Pending</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="96"/>
+        <location filename="../src/newcallmodel.cpp" line="98"/>
         <source>Undecipherable</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="97"/>
+        <location filename="../src/newcallmodel.cpp" line="99"/>
         <source>Internal Server Error</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="98"/>
+        <location filename="../src/newcallmodel.cpp" line="100"/>
         <source>Not Implemented</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="99"/>
+        <location filename="../src/newcallmodel.cpp" line="101"/>
         <source>Bad Gateway</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="100"/>
+        <location filename="../src/newcallmodel.cpp" line="102"/>
         <source>Service Unavailable</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="101"/>
+        <location filename="../src/newcallmodel.cpp" line="103"/>
         <source>Server Timeout</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="102"/>
+        <location filename="../src/newcallmodel.cpp" line="104"/>
         <source>Version Not Supported</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="103"/>
+        <location filename="../src/newcallmodel.cpp" line="105"/>
         <source>Message Too Large</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="104"/>
+        <location filename="../src/newcallmodel.cpp" line="106"/>
         <source>Precondition Failure</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="105"/>
+        <location filename="../src/newcallmodel.cpp" line="107"/>
         <source>Busy Everywhere</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="106"/>
+        <location filename="../src/newcallmodel.cpp" line="108"/>
         <source>Call Refused</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="107"/>
+        <location filename="../src/newcallmodel.cpp" line="109"/>
         <source>Does Not Exist Anywhere</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="../src/newcallmodel.cpp" line="108"/>
+        <location filename="../src/newcallmodel.cpp" line="110"/>
         <source>Not Acceptable Anywhere</source>
         <translation type="unfinished"/>
     </message>
@@ -403,143 +414,206 @@
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="32"/>
+        <source>Show available plugins</source>
+        <translation>Pokaż dostępne wtyczki</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="33"/>
         <source>Place audio call</source>
         <translation>Wykonaj połączenie głosowe</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="33"/>
+        <location filename="../src/chatview.cpp" line="34"/>
         <source>Add to conversations</source>
         <translation>Dodaj do rozmowy</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="34"/>
+        <location filename="../src/chatview.cpp" line="35"/>
         <source>Unban contact</source>
         <translation>Odblokuj konto</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="35"/>
+        <location filename="../src/chatview.cpp" line="36"/>
         <source>Send</source>
         <translation>Wyślij</translation>
     </message>
-    <message>
-        <location filename="../src/chatview.cpp" line="36"/>
-        <source>Options</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <location filename="../src/chatview.cpp" line="37"/>
-        <source>Jump to latest</source>
-        <translation type="unfinished"/>
+        <source>Options</source>
+        <translation>Opcje</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="38"/>
+        <source>Jump to latest</source>
+        <translation>Skocz do najnowszych</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="39"/>
         <source>Send file</source>
         <translation>Wyślij plik</translation>
     </message>
-    <message>
-        <location filename="../src/chatview.cpp" line="39"/>
-        <source>Leave video message</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <location filename="../src/chatview.cpp" line="40"/>
-        <source>Leave audio message</source>
-        <translation type="unfinished"/>
+        <source>Add emoji</source>
+        <translation>Dodaj emoji</translation>
     </message>
     <message>
         <location filename="../src/chatview.cpp" line="41"/>
-        <location filename="../src/chatview.cpp" line="58"/>
+        <source>Leave video message</source>
+        <translation>Zostaw wiadomość wideo</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="42"/>
+        <source>Leave audio message</source>
+        <translation>Zostaw wiadomość głosową</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="44"/>
+        <source>Copy to downloads</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="45"/>
+        <source>Write to {0}</source>
+        <translation>Napisz do {0}</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="50"/>
+        <source>has sent you a conversation request.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="52"/>
+        <source>Hello, do you want to join the conversation?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="54"/>
+        <source>You have accepted the conversation request.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="56"/>
+        <source>We are waiting for another device to synchronize the conversation.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="67"/>
         <source>Accept</source>
         <translation>Akceptuj</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="42"/>
-        <location filename="../src/chatview.cpp" line="59"/>
+        <location filename="../src/chatview.cpp" line="68"/>
         <source>Refuse</source>
         <translation>Odmów</translation>
     </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="71"/>
+        <source>Unable to make contact</source>
+        <translation>Nie udało się nawiązać kontaktu</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="76"/>
+        <source>Waiting for contact</source>
+        <translation>Czekanie na kontakt</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="77"/>
+        <source>Incoming transfer</source>
+        <translation>Przychodzący transfer</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="78"/>
+        <source>Timed out waiting for contact</source>
+        <translation>Przekroczono czas czekając na kontakt</translation>
+    </message>
     <message>
         <location filename="../src/chatview.cpp" line="43"/>
         <source>Block</source>
         <translation>Blokuj</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="44"/>
-        <source>Type a message</source>
-        <translation>Napisz wiadomość</translation>
-    </message>
-    <message>
-        <location filename="../src/chatview.cpp" line="46"/>
+        <location filename="../src/chatview.cpp" line="47"/>
         <source>Note: an interaction will create a new contact.</source>
         <translation>Uwaga: interakcja utworzy nowy kontakt.</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="47"/>
+        <location filename="../src/chatview.cpp" line="48"/>
         <source>is not in your contacts</source>
-        <translation type="unfinished"/>
+        <translation>nie jest w twoich kontaktach</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="49"/>
+        <location filename="../src/chatview.cpp" line="58"/>
         <source>Note: you can automatically accept this invitation by sending a message.</source>
         <translation>Uwaga: możesz automatycznie zaakceptować to zaproszenie poprzez wysłanie wiadmości.</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="50"/>
+        <location filename="../src/chatview.cpp" line="59"/>
         <source>{0} days ago</source>
-        <translation type="unfinished"/>
+        <translation>{0} dni temu</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="51"/>
+        <location filename="../src/chatview.cpp" line="60"/>
         <source>{0} hours ago</source>
-        <translation type="unfinished"/>
+        <translation>{0} godzin temu</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="53"/>
+        <location filename="../src/chatview.cpp" line="62"/>
         <source>{0} minutes ago</source>
-        <translation type="unfinished"/>
+        <translation>{0} minut temu</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="50"/>
+        <location filename="../src/chatview.cpp" line="74"/>
+        <source>Canceled</source>
+        <translation>Anulowano</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="75"/>
+        <source>Ongoing</source>
+        <translation>W trakcie</translation>
+    </message>
+    <message>
+        <location filename="../src/chatview.cpp" line="59"/>
         <source>%d days ago</source>
         <translation>%d dni temu </translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="51"/>
+        <location filename="../src/chatview.cpp" line="60"/>
         <source>%d hours ago</source>
         <translation>%d godzin temu</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="53"/>
+        <location filename="../src/chatview.cpp" line="62"/>
         <source>%d minutes ago</source>
         <translation>%d minut temu</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="54"/>
+        <location filename="../src/chatview.cpp" line="63"/>
         <source>one day ago</source>
         <translation>jeden dzień temu</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="55"/>
+        <location filename="../src/chatview.cpp" line="64"/>
         <source>one hour ago</source>
         <translation>jedną godzinę temu</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="56"/>
+        <location filename="../src/chatview.cpp" line="65"/>
         <source>just now</source>
         <translation>teraz</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="57"/>
+        <location filename="../src/chatview.cpp" line="66"/>
         <source>Failure</source>
         <translation>Nie powiodło się</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="60"/>
+        <location filename="../src/chatview.cpp" line="69"/>
         <source>Delete</source>
         <translation>Usuń</translation>
     </message>
     <message>
-        <location filename="../src/chatview.cpp" line="61"/>
+        <location filename="../src/chatview.cpp" line="70"/>
         <source>Retry</source>
         <translation>Ponów</translation>
     </message>
@@ -547,22 +621,22 @@
 <context>
     <name>lrc::ContactModelPimpl</name>
     <message>
-        <location filename="../src/contactmodel.cpp" line="455"/>
+        <location filename="../src/contactmodel.cpp" line="474"/>
         <source>Searching…</source>
         <translation>Szukanie...</translation>
     </message>
     <message>
-        <location filename="../src/contactmodel.cpp" line="950"/>
+        <location filename="../src/contactmodel.cpp" line="999"/>
         <source>Invalid ID</source>
         <translation>Nieprawidłowe ID</translation>
     </message>
     <message>
-        <location filename="../src/contactmodel.cpp" line="953"/>
-        <source>Registered name not found</source>
-        <translation type="unfinished"/>
+        <location filename="../src/contactmodel.cpp" line="1002"/>
+        <source>Username not found</source>
+        <translation>Nazwa użytkownika nieznaleziona</translation>
     </message>
     <message>
-        <location filename="../src/contactmodel.cpp" line="956"/>
+        <location filename="../src/contactmodel.cpp" line="1005"/>
         <source>Couldn&apos;t lookup…</source>
         <translation type="unfinished"/>
     </message>
@@ -570,7 +644,7 @@
 <context>
     <name>lrc::api::ContactModel</name>
     <message>
-        <location filename="../src/contactmodel.cpp" line="419"/>
+        <location filename="../src/contactmodel.cpp" line="435"/>
         <source>Bad URI scheme</source>
         <translation>Złe URI</translation>
     </message>
