@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 #
 # Copyright (C) 2016-2021 Savoir-faire Linux Inc.
 #
@@ -21,8 +21,15 @@
 
 #
 # This script syncs and deploys packages from packages/distro.
-# It should be ran from the project root directory.
+# It should be run from the project root directory.
 #
+# Requirements
+# - createrepo-c
+# - dpkg
+# - reprepro
+# - rpm
+# - rsync
+# - snapcraft
 
 # Exit immediately if a command exits with a non-zero status
 set -e
@@ -31,37 +38,10 @@ set -e
 ## Debian / Ubuntu packaging ##
 ###############################
 
-function fetch_qt_deb()
-{
-    if [ -f "${SSH_IDENTIY_FILE}" ];
-    then
-        RSYNC_RSH="ssh -i ${SSH_IDENTIY_FILE}"
-    fi
-
-    echo "#####################"
-    echo "## fetching qt deb ##"
-    echo "#####################"
-    echo "Using RSYNC_RSH='${RSYNC_RSH}'"
-    rsync --archive --verbose \
-          ${REMOTE_REPOSITORY_LOCATION}/${DISTRIBUTION}_qt/pool/main/libq/libqt-jami/*.deb \
-          ${DISTRIBUTION_REPOSITOIRY_FOLDER}_qt/
-}
-
 function package_deb()
 {
-    DISTRIBUTION_REPOSITOIRY_FOLDER=$(realpath repositories)/${DISTRIBUTION}
-    mkdir -p ${DISTRIBUTION_REPOSITOIRY_FOLDER}
-    mkdir -p ${DISTRIBUTION_REPOSITOIRY_FOLDER}_qt
-
-    ###########################################################
-    ## fetch qt deb (if not currently building a qt package) ##
-    ###########################################################
-    case "${DISTRIBUTION}" in
-        *_qt) ;;
-        *)
-            fetch_qt_deb
-            ;;
-    esac
+    DISTRIBUTION_REPOSITORY_FOLDER=$(realpath repositories)/${DISTRIBUTION}
+    mkdir -p ${DISTRIBUTION_REPOSITORY_FOLDER}
 
     ##################################################
     ## Create local repository for the given distro ##
@@ -70,10 +50,10 @@ function package_deb()
     echo "## Creating repository ##"
     echo "#########################"
 
-    mkdir ${DISTRIBUTION_REPOSITOIRY_FOLDER}/conf
+    mkdir ${DISTRIBUTION_REPOSITORY_FOLDER}/conf
 
     # Distributions file
-    cat << EOF > ${DISTRIBUTION_REPOSITOIRY_FOLDER}/conf/distributions
+    cat << EOF > ${DISTRIBUTION_REPOSITORY_FOLDER}/conf/distributions
 Origin: jami
 Label: Jami ${DISTRIBUTION} Repository
 Codename: jami
@@ -95,61 +75,58 @@ EOF
     ####################################
     ## Add packages to the repository ##
     ####################################
-    packages="packages/${DISTRIBUTION}*/*.deb"
-    case "${DISTRIBUTION}" in
-        *_qt) ;;
-        *)
-            packages="${packages} ${DISTRIBUTION_REPOSITOIRY_FOLDER}_qt/*.deb"
-            ;;
-    esac
-    for package in ${packages}; do
-        # Sign the deb
+    # Note: reprepro currently only accepts .deb files as input, but
+    # Ubuntu generates their debug symbol packages as .ddeb (see:
+    # https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=730572).  As
+    # these are just regular Debian packages, simply append the .deb
+    # extension to their file name to work around this.
+    find ./packages -type f -name '*.ddeb' -print0 | xargs -0 -I{} mv {} {}.deb
+
+    for package in packages/${DISTRIBUTION}*/*.deb; do
         echo "## signing: ${package} ##"
         dpkg-sig -k ${KEYID} --sign builder ${package}
 
-        # Include the deb
         echo "## including ${package} ##"
         package_name=$(dpkg -I ${package} | grep -m 1 Package: | awk '{print $2}')
         package_arch=$(dpkg -I ${package} | grep -m 1 Architecture: | awk '{print $2}')
+
         if [ ${package_arch} = "all" ]; then
             # Removing to avoid the error of adding the same deb twice.
             # This happens with arch all packages, which are generated in amd64 and i386.
-            reprepro --verbose --basedir ${DISTRIBUTION_REPOSITOIRY_FOLDER} remove jami ${package_name}
+            reprepro --verbose --basedir ${DISTRIBUTION_REPOSITORY_FOLDER} remove jami ${package_name}
             # TODO: Remove when April 2024 comes.
-            reprepro --verbose --basedir ${DISTRIBUTION_REPOSITOIRY_FOLDER} remove ring ${package_name}
+            reprepro --verbose --basedir ${DISTRIBUTION_REPOSITORY_FOLDER} remove ring ${package_name}
         fi
-        reprepro --verbose --basedir ${DISTRIBUTION_REPOSITOIRY_FOLDER} includedeb jami ${package}
+        reprepro --verbose --basedir ${DISTRIBUTION_REPOSITORY_FOLDER} includedeb jami ${package}
         # TODO: Remove when April 2024 comes.
-        reprepro --verbose --basedir ${DISTRIBUTION_REPOSITOIRY_FOLDER} includedeb ring ${package}
+        reprepro --verbose --basedir ${DISTRIBUTION_REPOSITORY_FOLDER} includedeb ring ${package}
     done
 
     # Rebuild the index
-    reprepro --verbose --basedir ${DISTRIBUTION_REPOSITOIRY_FOLDER} export jami
+    reprepro --verbose --basedir ${DISTRIBUTION_REPOSITORY_FOLDER} export jami
     # TODO: Remove when April 2024 comes.
-    reprepro --verbose --basedir ${DISTRIBUTION_REPOSITOIRY_FOLDER} export ring
+    reprepro --verbose --basedir ${DISTRIBUTION_REPOSITORY_FOLDER} export ring
 
     # Show the contents
-    reprepro --verbose --basedir ${DISTRIBUTION_REPOSITOIRY_FOLDER} list jami
+    reprepro --verbose --basedir ${DISTRIBUTION_REPOSITORY_FOLDER} list jami
     # TODO: Remove when April 2024 comes.
-    reprepro --verbose --basedir ${DISTRIBUTION_REPOSITOIRY_FOLDER} list ring
+    reprepro --verbose --basedir ${DISTRIBUTION_REPOSITORY_FOLDER} list ring
 
     #######################################
     ## create the manual download folder ##
     #######################################
-    if ls packages/${DISTRIBUTION}*_oci &> /dev/null; then
-      DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER=$(realpath manual-download)/${DISTRIBUTION}
-      mkdir -p ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}
-      NAME_PATTERN=jami-all_????????.*\~dfsg*.deb
-      cp packages/${DISTRIBUTION}*_oci/${NAME_PATTERN} ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}
-      for package in ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}/${NAME_PATTERN} ; do
-          package_name=$(dpkg -I ${package} | grep -m 1 Package: | awk '{print $2}')
-          package_arch=$(dpkg -I ${package} | grep -m 1 Architecture: | awk '{print $2}')
-          package_shortname=${package_name}_${package_arch}.deb
-          rm -f ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}/${package_shortname}
-          cp ${package} ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}/${package_shortname}
-      done
-    else
-      echo "WARNING: OCI packages directory not found"
+    NAME_PATTERN=jami-all_????????.*\~dfsg*.deb
+    if ls packages/${DISTRIBUTION}/${NAME_PATTERN} &> /dev/null; then
+        DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER=$(realpath manual-download)/${DISTRIBUTION}
+        mkdir -p ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}
+        cp packages/${DISTRIBUTION}/${NAME_PATTERN} ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}
+        for package in ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}/${NAME_PATTERN} ; do
+            package_name=$(dpkg -I ${package} | grep -m 1 Package: | awk '{print $2}')
+            package_arch=$(dpkg -I ${package} | grep -m 1 Architecture: | awk '{print $2}')
+            package_shortname=${package_name}_${package_arch}.deb
+            rm -f ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}/${package_shortname}
+            cp ${package} ${DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER}/${package_shortname}
+        done
     fi
 }
 
@@ -170,8 +147,8 @@ function package_rpm()
     local name
     local baseurl
 
-    DISTRIBUTION_REPOSITOIRY_FOLDER=$(realpath repositories)/${DISTRIBUTION}
-    mkdir -p ${DISTRIBUTION_REPOSITOIRY_FOLDER}
+    DISTRIBUTION_REPOSITORY_FOLDER=$(realpath repositories)/${DISTRIBUTION}
+    mkdir -p ${DISTRIBUTION_REPOSITORY_FOLDER}
 
     # .repo file
     if [ "${DISTRIBUTION:0:19}" == "opensuse-tumbleweed" ]; then
@@ -182,7 +159,7 @@ function package_rpm()
         baseurl="https://dl.jami.net/nightly/${DISTRIBUTION%_*}_\$releasever"
     fi
 
-    cat << EOF > ${DISTRIBUTION_REPOSITOIRY_FOLDER}/jami-nightly.repo
+    cat << EOF > ${DISTRIBUTION_REPOSITORY_FOLDER}/jami-nightly.repo
 [jami]
 name=$name
 baseurl=$baseurl
@@ -209,11 +186,11 @@ EOF
 
     for package in packages/${DISTRIBUTION}*/*.rpm; do
         rpmsign --resign --key-id=${KEYID} ${package}
-        cp ${package} ${DISTRIBUTION_REPOSITOIRY_FOLDER}
+        cp ${package} ${DISTRIBUTION_REPOSITORY_FOLDER}
     done
 
     # Create the repo
-    createrepo --update ${DISTRIBUTION_REPOSITOIRY_FOLDER}
+    createrepo_c --update ${DISTRIBUTION_REPOSITORY_FOLDER}
 
     #######################################
     ## create the manual download folder ##
@@ -249,9 +226,9 @@ function package_snap()
     echo "####################"
 
     if [[ "${CHANNEL:0:19}" == "internal_experiment" ]]; then
-        DISTRIBUTION_REPOSITOIRY_FOLDER=$(realpath repositories)/${DISTRIBUTION}
-        mkdir -p ${DISTRIBUTION_REPOSITOIRY_FOLDER}
-        cp packages/${DISTRIBUTION}*/*.snap ${DISTRIBUTION_REPOSITOIRY_FOLDER}/
+        DISTRIBUTION_REPOSITORY_FOLDER=$(realpath repositories)/${DISTRIBUTION}
+        mkdir -p ${DISTRIBUTION_REPOSITORY_FOLDER}
+        cp packages/${DISTRIBUTION}*/*.snap ${DISTRIBUTION_REPOSITORY_FOLDER}/
     elif [[ "${CHANNEL:0:7}" == "nightly" ]]; then
         snapcraft login --with ${SNAPCRAFT_LOGIN}
         snapcraft push packages/${DISTRIBUTION}*/*.snap --release edge
@@ -268,9 +245,9 @@ function package_snap()
 
 function deploy()
 {
-    if [ -f "${SSH_IDENTIY_FILE}" ];
+    if [ -f "${SSH_IDENTITY_FILE}" ];
     then
-        RSYNC_RSH="ssh -i ${SSH_IDENTIY_FILE}"
+        export RSYNC_RSH="ssh -i ${SSH_IDENTITY_FILE}"
     fi
 
     echo "##########################"
@@ -278,7 +255,7 @@ function deploy()
     echo "##########################"
     echo "Using RSYNC_RSH='${RSYNC_RSH}'"
     rsync --archive --recursive --verbose \
-          --delete ${DISTRIBUTION_REPOSITOIRY_FOLDER} \
+          --delete ${DISTRIBUTION_REPOSITORY_FOLDER} \
           ${REMOTE_REPOSITORY_LOCATION}
 
     echo "#####################################"
@@ -317,7 +294,7 @@ function remove-deployed-files()
     # remove deployed files
     rm -rf manual-download
     rm -rf repositories
-    rm -rf ${DISTRIBUTION_REPOSITOIRY_FOLDER}
+    rm -rf ${DISTRIBUTION_REPOSITORY_FOLDER}
 }
 
 for i in "$@"
@@ -340,7 +317,7 @@ case $i in
     shift
     ;;
     --remote-ssh-identity-file=*)
-    SSH_IDENTIY_FILE="${i#*=}"
+    SSH_IDENTITY_FILE="${i#*=}"
     shift
     ;;
     --snapcraft-login=*)
@@ -357,7 +334,7 @@ done
 
 if [ -z "${KEYID}" ];
 then
-    DISTRIBUTION_REPOSITOIRY_FOLDER=$(realpath repositories)/${DISTRIBUTION}
+    DISTRIBUTION_REPOSITORY_FOLDER=$(realpath repositories)/${DISTRIBUTION}
     DISTRIBUTION_MANUAL_DOWNLOAD_FOLDER=$(realpath manual-download)/${DISTRIBUTION}
     deploy
     remove-deployed-files
